# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.sheet.accessible_cell import AccessibleCell as AccessibleCell
from .._pyi.sheet.accessible_csv_cell import AccessibleCsvCell as AccessibleCsvCell
from .._pyi.sheet.accessible_csv_ruler import AccessibleCsvRuler as AccessibleCsvRuler
from .._pyi.sheet.accessible_csv_table import AccessibleCsvTable as AccessibleCsvTable
from .._pyi.sheet.accessible_page_header_footer_areas_view import AccessiblePageHeaderFooterAreasView as AccessiblePageHeaderFooterAreasView
from .._pyi.sheet.accessible_spreadsheet import AccessibleSpreadsheet as AccessibleSpreadsheet
from .._pyi.sheet.accessible_spreadsheet_document_view import AccessibleSpreadsheetDocumentView as AccessibleSpreadsheetDocumentView
from .._pyi.sheet.accessible_spreadsheet_page_view import AccessibleSpreadsheetPageView as AccessibleSpreadsheetPageView
from .._pyi.sheet.activation_event import ActivationEvent as ActivationEvent
from .._pyi.sheet.add_in import AddIn as AddIn
from .._pyi.sheet.cell_annotation import CellAnnotation as CellAnnotation
from .._pyi.sheet.cell_annotation_shape import CellAnnotationShape as CellAnnotationShape
from .._pyi.sheet.cell_annotations import CellAnnotations as CellAnnotations
from .._pyi.sheet.cell_annotations_enumeration import CellAnnotationsEnumeration as CellAnnotationsEnumeration
from .._pyi.sheet.cell_area_link import CellAreaLink as CellAreaLink
from .._pyi.sheet.cell_area_links import CellAreaLinks as CellAreaLinks
from .._pyi.sheet.cell_area_links_enumeration import CellAreaLinksEnumeration as CellAreaLinksEnumeration
from .._pyi.sheet.cell_format_ranges import CellFormatRanges as CellFormatRanges
from .._pyi.sheet.cell_format_ranges_enumeration import CellFormatRangesEnumeration as CellFormatRangesEnumeration
from .._pyi.sheet.cells import Cells as Cells
from .._pyi.sheet.cells_enumeration import CellsEnumeration as CellsEnumeration
from .._pyi.sheet.color_scale import ColorScale as ColorScale
from .._pyi.sheet.complex_reference import ComplexReference as ComplexReference
from .._pyi.sheet.condition_format_entry import ConditionFormatEntry as ConditionFormatEntry
from .._pyi.sheet.conditional_format import ConditionalFormat as ConditionalFormat
from .._pyi.sheet.consolidation_descriptor import ConsolidationDescriptor as ConsolidationDescriptor
from .._pyi.sheet.dde_item_info import DDEItemInfo as DDEItemInfo
from .._pyi.sheet.dde_link import DDELink as DDELink
from .._pyi.sheet.dde_link_info import DDELinkInfo as DDELinkInfo
from .._pyi.sheet.dde_links import DDELinks as DDELinks
from .._pyi.sheet.dde_links_enumeration import DDELinksEnumeration as DDELinksEnumeration
from .._pyi.sheet.data_bar import DataBar as DataBar
from .._pyi.sheet.data_pilot_descriptor import DataPilotDescriptor as DataPilotDescriptor
from .._pyi.sheet.data_pilot_field import DataPilotField as DataPilotField
from .._pyi.sheet.data_pilot_field_auto_show_info import DataPilotFieldAutoShowInfo as DataPilotFieldAutoShowInfo
from .._pyi.sheet.data_pilot_field_filter import DataPilotFieldFilter as DataPilotFieldFilter
from .._pyi.sheet.data_pilot_field_group import DataPilotFieldGroup as DataPilotFieldGroup
from .._pyi.sheet.data_pilot_field_group_enumeration import DataPilotFieldGroupEnumeration as DataPilotFieldGroupEnumeration
from .._pyi.sheet.data_pilot_field_group_info import DataPilotFieldGroupInfo as DataPilotFieldGroupInfo
from .._pyi.sheet.data_pilot_field_group_item import DataPilotFieldGroupItem as DataPilotFieldGroupItem
from .._pyi.sheet.data_pilot_field_groups import DataPilotFieldGroups as DataPilotFieldGroups
from .._pyi.sheet.data_pilot_field_groups_enumeration import DataPilotFieldGroupsEnumeration as DataPilotFieldGroupsEnumeration
from .._pyi.sheet.data_pilot_field_layout_info import DataPilotFieldLayoutInfo as DataPilotFieldLayoutInfo
from .._pyi.sheet.data_pilot_field_reference import DataPilotFieldReference as DataPilotFieldReference
from .._pyi.sheet.data_pilot_field_sort_info import DataPilotFieldSortInfo as DataPilotFieldSortInfo
from .._pyi.sheet.data_pilot_fields import DataPilotFields as DataPilotFields
from .._pyi.sheet.data_pilot_fields_enumeration import DataPilotFieldsEnumeration as DataPilotFieldsEnumeration
from .._pyi.sheet.data_pilot_item import DataPilotItem as DataPilotItem
from .._pyi.sheet.data_pilot_items import DataPilotItems as DataPilotItems
from .._pyi.sheet.data_pilot_items_enumeration import DataPilotItemsEnumeration as DataPilotItemsEnumeration
from .._pyi.sheet.data_pilot_source import DataPilotSource as DataPilotSource
from .._pyi.sheet.data_pilot_source_dimension import DataPilotSourceDimension as DataPilotSourceDimension
from .._pyi.sheet.data_pilot_source_dimensions import DataPilotSourceDimensions as DataPilotSourceDimensions
from .._pyi.sheet.data_pilot_source_hierarchies import DataPilotSourceHierarchies as DataPilotSourceHierarchies
from .._pyi.sheet.data_pilot_source_hierarchy import DataPilotSourceHierarchy as DataPilotSourceHierarchy
from .._pyi.sheet.data_pilot_source_level import DataPilotSourceLevel as DataPilotSourceLevel
from .._pyi.sheet.data_pilot_source_levels import DataPilotSourceLevels as DataPilotSourceLevels
from .._pyi.sheet.data_pilot_source_member import DataPilotSourceMember as DataPilotSourceMember
from .._pyi.sheet.data_pilot_source_members import DataPilotSourceMembers as DataPilotSourceMembers
from .._pyi.sheet.data_pilot_table import DataPilotTable as DataPilotTable
from .._pyi.sheet.data_pilot_table_header_data import DataPilotTableHeaderData as DataPilotTableHeaderData
from .._pyi.sheet.data_pilot_table_position_data import DataPilotTablePositionData as DataPilotTablePositionData
from .._pyi.sheet.data_pilot_table_result_data import DataPilotTableResultData as DataPilotTableResultData
from .._pyi.sheet.data_pilot_tables import DataPilotTables as DataPilotTables
from .._pyi.sheet.data_pilot_tables_enumeration import DataPilotTablesEnumeration as DataPilotTablesEnumeration
from .._pyi.sheet.data_result import DataResult as DataResult
from .._pyi.sheet.database_import_descriptor import DatabaseImportDescriptor as DatabaseImportDescriptor
from .._pyi.sheet.database_range import DatabaseRange as DatabaseRange
from .._pyi.sheet.database_ranges import DatabaseRanges as DatabaseRanges
from .._pyi.sheet.database_ranges_enumeration import DatabaseRangesEnumeration as DatabaseRangesEnumeration
from .._pyi.sheet.date_condition import DateCondition as DateCondition
from .._pyi.sheet.document_settings import DocumentSettings as DocumentSettings
from .._pyi.sheet.external_doc_link import ExternalDocLink as ExternalDocLink
from .._pyi.sheet.external_doc_links import ExternalDocLinks as ExternalDocLinks
from .._pyi.sheet.external_link_info import ExternalLinkInfo as ExternalLinkInfo
from .._pyi.sheet.external_reference import ExternalReference as ExternalReference
from .._pyi.sheet.external_sheet_cache import ExternalSheetCache as ExternalSheetCache
from .._pyi.sheet.filter_field_value import FilterFieldValue as FilterFieldValue
from .._pyi.sheet.filter_formula_parser import FilterFormulaParser as FilterFormulaParser
from .._pyi.sheet.formula_op_code_map_entry import FormulaOpCodeMapEntry as FormulaOpCodeMapEntry
from .._pyi.sheet.formula_op_code_mapper import FormulaOpCodeMapper as FormulaOpCodeMapper
from .._pyi.sheet.formula_parser import FormulaParser as FormulaParser
from .._pyi.sheet.formula_token import FormulaToken as FormulaToken
from .._pyi.sheet.function_access import FunctionAccess as FunctionAccess
from .._pyi.sheet.function_argument import FunctionArgument as FunctionArgument
from .._pyi.sheet.function_description import FunctionDescription as FunctionDescription
from .._pyi.sheet.function_description_enumeration import FunctionDescriptionEnumeration as FunctionDescriptionEnumeration
from .._pyi.sheet.function_descriptions import FunctionDescriptions as FunctionDescriptions
from .._pyi.sheet.global_sheet_settings import GlobalSheetSettings as GlobalSheetSettings
from .._pyi.sheet.goal_result import GoalResult as GoalResult
from .._pyi.sheet.header_footer_content import HeaderFooterContent as HeaderFooterContent
from .._pyi.sheet.icon_set import IconSet as IconSet
from .._pyi.sheet.label_range import LabelRange as LabelRange
from .._pyi.sheet.label_ranges import LabelRanges as LabelRanges
from .._pyi.sheet.label_ranges_enumeration import LabelRangesEnumeration as LabelRangesEnumeration
from .._pyi.sheet.localized_name import LocalizedName as LocalizedName
from .._pyi.sheet.member_result import MemberResult as MemberResult
from .._pyi.sheet.name_token import NameToken as NameToken
from .._pyi.sheet.named_range import NamedRange as NamedRange
from .._pyi.sheet.named_ranges import NamedRanges as NamedRanges
from .._pyi.sheet.named_ranges_enumeration import NamedRangesEnumeration as NamedRangesEnumeration
from .._pyi.sheet.no_convergence_exception import NoConvergenceException as NoConvergenceException
from .._pyi.sheet.range_selection_arguments import RangeSelectionArguments as RangeSelectionArguments
from .._pyi.sheet.range_selection_event import RangeSelectionEvent as RangeSelectionEvent
from .._pyi.sheet.recent_functions import RecentFunctions as RecentFunctions
from .._pyi.sheet.result_event import ResultEvent as ResultEvent
from .._pyi.sheet.scenario import Scenario as Scenario
from .._pyi.sheet.scenarios import Scenarios as Scenarios
from .._pyi.sheet.scenarios_enumeration import ScenariosEnumeration as ScenariosEnumeration
from .._pyi.sheet.shape import Shape as Shape
from .._pyi.sheet.sheet_cell import SheetCell as SheetCell
from .._pyi.sheet.sheet_cell_cursor import SheetCellCursor as SheetCellCursor
from .._pyi.sheet.sheet_cell_range import SheetCellRange as SheetCellRange
from .._pyi.sheet.sheet_cell_ranges import SheetCellRanges as SheetCellRanges
from .._pyi.sheet.sheet_cell_ranges_enumeration import SheetCellRangesEnumeration as SheetCellRangesEnumeration
from .._pyi.sheet.sheet_filter_descriptor import SheetFilterDescriptor as SheetFilterDescriptor
from .._pyi.sheet.sheet_link import SheetLink as SheetLink
from .._pyi.sheet.sheet_links import SheetLinks as SheetLinks
from .._pyi.sheet.sheet_links_enumeration import SheetLinksEnumeration as SheetLinksEnumeration
from .._pyi.sheet.sheet_ranges_query import SheetRangesQuery as SheetRangesQuery
from .._pyi.sheet.sheet_sort_descriptor import SheetSortDescriptor as SheetSortDescriptor
from .._pyi.sheet.sheet_sort_descriptor2 import SheetSortDescriptor2 as SheetSortDescriptor2
from .._pyi.sheet.single_reference import SingleReference as SingleReference
from .._pyi.sheet.solver import Solver as Solver
from .._pyi.sheet.solver_constraint import SolverConstraint as SolverConstraint
from .._pyi.sheet.spreadsheet import Spreadsheet as Spreadsheet
from .._pyi.sheet.spreadsheet_document import SpreadsheetDocument as SpreadsheetDocument
from .._pyi.sheet.spreadsheet_document_settings import SpreadsheetDocumentSettings as SpreadsheetDocumentSettings
from .._pyi.sheet.spreadsheet_draw_page import SpreadsheetDrawPage as SpreadsheetDrawPage
from .._pyi.sheet.spreadsheet_view import SpreadsheetView as SpreadsheetView
from .._pyi.sheet.spreadsheet_view_pane import SpreadsheetViewPane as SpreadsheetViewPane
from .._pyi.sheet.spreadsheet_view_panes_enumeration import SpreadsheetViewPanesEnumeration as SpreadsheetViewPanesEnumeration
from .._pyi.sheet.spreadsheet_view_settings import SpreadsheetViewSettings as SpreadsheetViewSettings
from .._pyi.sheet.spreadsheets import Spreadsheets as Spreadsheets
from .._pyi.sheet.spreadsheets_enumeration import SpreadsheetsEnumeration as SpreadsheetsEnumeration
from .._pyi.sheet.sub_total_column import SubTotalColumn as SubTotalColumn
from .._pyi.sheet.sub_total_descriptor import SubTotalDescriptor as SubTotalDescriptor
from .._pyi.sheet.sub_total_field import SubTotalField as SubTotalField
from .._pyi.sheet.sub_total_fields_enumeration import SubTotalFieldsEnumeration as SubTotalFieldsEnumeration
from .._pyi.sheet.table_auto_format import TableAutoFormat as TableAutoFormat
from .._pyi.sheet.table_auto_format_enumeration import TableAutoFormatEnumeration as TableAutoFormatEnumeration
from .._pyi.sheet.table_auto_format_field import TableAutoFormatField as TableAutoFormatField
from .._pyi.sheet.table_auto_formats import TableAutoFormats as TableAutoFormats
from .._pyi.sheet.table_auto_formats_enumeration import TableAutoFormatsEnumeration as TableAutoFormatsEnumeration
from .._pyi.sheet.table_cell_style import TableCellStyle as TableCellStyle
from .._pyi.sheet.table_conditional_entry import TableConditionalEntry as TableConditionalEntry
from .._pyi.sheet.table_conditional_entry_enumeration import TableConditionalEntryEnumeration as TableConditionalEntryEnumeration
from .._pyi.sheet.table_conditional_format import TableConditionalFormat as TableConditionalFormat
from .._pyi.sheet.table_filter_field import TableFilterField as TableFilterField
from .._pyi.sheet.table_filter_field2 import TableFilterField2 as TableFilterField2
from .._pyi.sheet.table_filter_field3 import TableFilterField3 as TableFilterField3
from .._pyi.sheet.table_page_break_data import TablePageBreakData as TablePageBreakData
from .._pyi.sheet.table_page_style import TablePageStyle as TablePageStyle
from .._pyi.sheet.table_validation import TableValidation as TableValidation
from .._pyi.sheet.unique_cell_format_ranges import UniqueCellFormatRanges as UniqueCellFormatRanges
from .._pyi.sheet.unique_cell_format_ranges_enumeration import UniqueCellFormatRangesEnumeration as UniqueCellFormatRangesEnumeration
from .._pyi.sheet.volatile_result import VolatileResult as VolatileResult
from .._pyi.sheet.x_activation_broadcaster import XActivationBroadcaster as XActivationBroadcaster
from .._pyi.sheet.x_activation_event_listener import XActivationEventListener as XActivationEventListener
from .._pyi.sheet.x_add_in import XAddIn as XAddIn
from .._pyi.sheet.x_area_link import XAreaLink as XAreaLink
from .._pyi.sheet.x_area_links import XAreaLinks as XAreaLinks
from .._pyi.sheet.x_array_formula_range import XArrayFormulaRange as XArrayFormulaRange
from .._pyi.sheet.x_array_formula_tokens import XArrayFormulaTokens as XArrayFormulaTokens
from .._pyi.sheet.x_calculatable import XCalculatable as XCalculatable
from .._pyi.sheet.x_cell_addressable import XCellAddressable as XCellAddressable
from .._pyi.sheet.x_cell_format_ranges_supplier import XCellFormatRangesSupplier as XCellFormatRangesSupplier
from .._pyi.sheet.x_cell_range_addressable import XCellRangeAddressable as XCellRangeAddressable
from .._pyi.sheet.x_cell_range_data import XCellRangeData as XCellRangeData
from .._pyi.sheet.x_cell_range_formula import XCellRangeFormula as XCellRangeFormula
from .._pyi.sheet.x_cell_range_movement import XCellRangeMovement as XCellRangeMovement
from .._pyi.sheet.x_cell_range_referrer import XCellRangeReferrer as XCellRangeReferrer
from .._pyi.sheet.x_cell_ranges_access import XCellRangesAccess as XCellRangesAccess
from .._pyi.sheet.x_cell_ranges_query import XCellRangesQuery as XCellRangesQuery
from .._pyi.sheet.x_cell_series import XCellSeries as XCellSeries
from .._pyi.sheet.x_color_scale_entry import XColorScaleEntry as XColorScaleEntry
from .._pyi.sheet.x_compatibility_names import XCompatibilityNames as XCompatibilityNames
from .._pyi.sheet.x_condition_entry import XConditionEntry as XConditionEntry
from .._pyi.sheet.x_conditional_format import XConditionalFormat as XConditionalFormat
from .._pyi.sheet.x_conditional_formats import XConditionalFormats as XConditionalFormats
from .._pyi.sheet.x_consolidatable import XConsolidatable as XConsolidatable
from .._pyi.sheet.x_consolidation_descriptor import XConsolidationDescriptor as XConsolidationDescriptor
from .._pyi.sheet.xdde_link import XDDELink as XDDELink
from .._pyi.sheet.xdde_link_results import XDDELinkResults as XDDELinkResults
from .._pyi.sheet.xdde_links import XDDELinks as XDDELinks
from .._pyi.sheet.x_data_bar_entry import XDataBarEntry as XDataBarEntry
from .._pyi.sheet.x_data_pilot_data_layout_field_supplier import XDataPilotDataLayoutFieldSupplier as XDataPilotDataLayoutFieldSupplier
from .._pyi.sheet.x_data_pilot_descriptor import XDataPilotDescriptor as XDataPilotDescriptor
from .._pyi.sheet.x_data_pilot_field import XDataPilotField as XDataPilotField
from .._pyi.sheet.x_data_pilot_field_grouping import XDataPilotFieldGrouping as XDataPilotFieldGrouping
from .._pyi.sheet.x_data_pilot_member_results import XDataPilotMemberResults as XDataPilotMemberResults
from .._pyi.sheet.x_data_pilot_results import XDataPilotResults as XDataPilotResults
from .._pyi.sheet.x_data_pilot_table import XDataPilotTable as XDataPilotTable
from .._pyi.sheet.x_data_pilot_table2 import XDataPilotTable2 as XDataPilotTable2
from .._pyi.sheet.x_data_pilot_tables import XDataPilotTables as XDataPilotTables
from .._pyi.sheet.x_data_pilot_tables_supplier import XDataPilotTablesSupplier as XDataPilotTablesSupplier
from .._pyi.sheet.x_database_range import XDatabaseRange as XDatabaseRange
from .._pyi.sheet.x_database_ranges import XDatabaseRanges as XDatabaseRanges
from .._pyi.sheet.x_dimensions_supplier import XDimensionsSupplier as XDimensionsSupplier
from .._pyi.sheet.x_document_auditing import XDocumentAuditing as XDocumentAuditing
from .._pyi.sheet.x_drill_down_data_supplier import XDrillDownDataSupplier as XDrillDownDataSupplier
from .._pyi.sheet.x_enhanced_mouse_click_broadcaster import XEnhancedMouseClickBroadcaster as XEnhancedMouseClickBroadcaster
from .._pyi.sheet.x_external_doc_link import XExternalDocLink as XExternalDocLink
from .._pyi.sheet.x_external_doc_links import XExternalDocLinks as XExternalDocLinks
from .._pyi.sheet.x_external_sheet_cache import XExternalSheetCache as XExternalSheetCache
from .._pyi.sheet.x_external_sheet_name import XExternalSheetName as XExternalSheetName
from .._pyi.sheet.x_fill_across_sheet import XFillAcrossSheet as XFillAcrossSheet
from .._pyi.sheet.x_filter_formula_parser import XFilterFormulaParser as XFilterFormulaParser
from .._pyi.sheet.x_formula_op_code_mapper import XFormulaOpCodeMapper as XFormulaOpCodeMapper
from .._pyi.sheet.x_formula_parser import XFormulaParser as XFormulaParser
from .._pyi.sheet.x_formula_query import XFormulaQuery as XFormulaQuery
from .._pyi.sheet.x_formula_tokens import XFormulaTokens as XFormulaTokens
from .._pyi.sheet.x_function_access import XFunctionAccess as XFunctionAccess
from .._pyi.sheet.x_function_descriptions import XFunctionDescriptions as XFunctionDescriptions
from .._pyi.sheet.x_global_sheet_settings import XGlobalSheetSettings as XGlobalSheetSettings
from .._pyi.sheet.x_goal_seek import XGoalSeek as XGoalSeek
from .._pyi.sheet.x_header_footer_content import XHeaderFooterContent as XHeaderFooterContent
from .._pyi.sheet.x_hierarchies_supplier import XHierarchiesSupplier as XHierarchiesSupplier
from .._pyi.sheet.x_icon_set_entry import XIconSetEntry as XIconSetEntry
from .._pyi.sheet.x_label_range import XLabelRange as XLabelRange
from .._pyi.sheet.x_label_ranges import XLabelRanges as XLabelRanges
from .._pyi.sheet.x_levels_supplier import XLevelsSupplier as XLevelsSupplier
from .._pyi.sheet.x_members_access import XMembersAccess as XMembersAccess
from .._pyi.sheet.x_members_supplier import XMembersSupplier as XMembersSupplier
from .._pyi.sheet.x_multi_formula_tokens import XMultiFormulaTokens as XMultiFormulaTokens
from .._pyi.sheet.x_multiple_operation import XMultipleOperation as XMultipleOperation
from .._pyi.sheet.x_named_range import XNamedRange as XNamedRange
from .._pyi.sheet.x_named_ranges import XNamedRanges as XNamedRanges
from .._pyi.sheet.x_print_areas import XPrintAreas as XPrintAreas
from .._pyi.sheet.x_range_selection import XRangeSelection as XRangeSelection
from .._pyi.sheet.x_range_selection_change_listener import XRangeSelectionChangeListener as XRangeSelectionChangeListener
from .._pyi.sheet.x_range_selection_listener import XRangeSelectionListener as XRangeSelectionListener
from .._pyi.sheet.x_recent_functions import XRecentFunctions as XRecentFunctions
from .._pyi.sheet.x_result_listener import XResultListener as XResultListener
from .._pyi.sheet.x_scenario import XScenario as XScenario
from .._pyi.sheet.x_scenario_enhanced import XScenarioEnhanced as XScenarioEnhanced
from .._pyi.sheet.x_scenarios import XScenarios as XScenarios
from .._pyi.sheet.x_scenarios_supplier import XScenariosSupplier as XScenariosSupplier
from .._pyi.sheet.x_selected_sheets_supplier import XSelectedSheetsSupplier as XSelectedSheetsSupplier
from .._pyi.sheet.x_sheet_annotation import XSheetAnnotation as XSheetAnnotation
from .._pyi.sheet.x_sheet_annotation_anchor import XSheetAnnotationAnchor as XSheetAnnotationAnchor
from .._pyi.sheet.x_sheet_annotation_shape_supplier import XSheetAnnotationShapeSupplier as XSheetAnnotationShapeSupplier
from .._pyi.sheet.x_sheet_annotations import XSheetAnnotations as XSheetAnnotations
from .._pyi.sheet.x_sheet_annotations_supplier import XSheetAnnotationsSupplier as XSheetAnnotationsSupplier
from .._pyi.sheet.x_sheet_auditing import XSheetAuditing as XSheetAuditing
from .._pyi.sheet.x_sheet_cell_cursor import XSheetCellCursor as XSheetCellCursor
from .._pyi.sheet.x_sheet_cell_range import XSheetCellRange as XSheetCellRange
from .._pyi.sheet.x_sheet_cell_range_container import XSheetCellRangeContainer as XSheetCellRangeContainer
from .._pyi.sheet.x_sheet_cell_ranges import XSheetCellRanges as XSheetCellRanges
from .._pyi.sheet.x_sheet_condition import XSheetCondition as XSheetCondition
from .._pyi.sheet.x_sheet_condition2 import XSheetCondition2 as XSheetCondition2
from .._pyi.sheet.x_sheet_conditional_entries import XSheetConditionalEntries as XSheetConditionalEntries
from .._pyi.sheet.x_sheet_conditional_entry import XSheetConditionalEntry as XSheetConditionalEntry
from .._pyi.sheet.x_sheet_filter_descriptor import XSheetFilterDescriptor as XSheetFilterDescriptor
from .._pyi.sheet.x_sheet_filter_descriptor2 import XSheetFilterDescriptor2 as XSheetFilterDescriptor2
from .._pyi.sheet.x_sheet_filter_descriptor3 import XSheetFilterDescriptor3 as XSheetFilterDescriptor3
from .._pyi.sheet.x_sheet_filterable import XSheetFilterable as XSheetFilterable
from .._pyi.sheet.x_sheet_filterable_ex import XSheetFilterableEx as XSheetFilterableEx
from .._pyi.sheet.x_sheet_linkable import XSheetLinkable as XSheetLinkable
from .._pyi.sheet.x_sheet_operation import XSheetOperation as XSheetOperation
from .._pyi.sheet.x_sheet_outline import XSheetOutline as XSheetOutline
from .._pyi.sheet.x_sheet_page_break import XSheetPageBreak as XSheetPageBreak
from .._pyi.sheet.x_sheet_pastable import XSheetPastable as XSheetPastable
from .._pyi.sheet.x_solver import XSolver as XSolver
from .._pyi.sheet.x_solver_description import XSolverDescription as XSolverDescription
from .._pyi.sheet.x_spreadsheet import XSpreadsheet as XSpreadsheet
from .._pyi.sheet.x_spreadsheet_document import XSpreadsheetDocument as XSpreadsheetDocument
from .._pyi.sheet.x_spreadsheet_view import XSpreadsheetView as XSpreadsheetView
from .._pyi.sheet.x_spreadsheets import XSpreadsheets as XSpreadsheets
from .._pyi.sheet.x_spreadsheets2 import XSpreadsheets2 as XSpreadsheets2
from .._pyi.sheet.x_sub_total_calculatable import XSubTotalCalculatable as XSubTotalCalculatable
from .._pyi.sheet.x_sub_total_descriptor import XSubTotalDescriptor as XSubTotalDescriptor
from .._pyi.sheet.x_sub_total_field import XSubTotalField as XSubTotalField
from .._pyi.sheet.x_unique_cell_format_ranges_supplier import XUniqueCellFormatRangesSupplier as XUniqueCellFormatRangesSupplier
from .._pyi.sheet.x_unnamed_database_ranges import XUnnamedDatabaseRanges as XUnnamedDatabaseRanges
from .._pyi.sheet.x_used_area_cursor import XUsedAreaCursor as XUsedAreaCursor
from .._pyi.sheet.x_view_freezable import XViewFreezable as XViewFreezable
from .._pyi.sheet.x_view_pane import XViewPane as XViewPane
from .._pyi.sheet.x_view_panes_supplier import XViewPanesSupplier as XViewPanesSupplier
from .._pyi.sheet.x_view_splitable import XViewSplitable as XViewSplitable
from .._pyi.sheet.x_volatile_result import XVolatileResult as XVolatileResult



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.uno
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class Uik(object):
    """
    Struct Class

    Specifies a universal interface key (globally unique).
    
    This struct is deprecated. Uiks are not used anymore.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API Uik <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1uno_1_1Uik.html>`_
    """
    typeName: Literal['com.sun.star.uno.Uik']

    def __init__(self, Data1: typing.Optional[int] = ..., Data2: typing.Optional[int] = ..., Data3: typing.Optional[int] = ..., Data4: typing.Optional[int] = ..., Data5: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Data1 (int, optional): Data1 value.
            Data2 (int, optional): Data2 value.
            Data3 (int, optional): Data3 value.
            Data4 (int, optional): Data4 value.
            Data5 (int, optional): Data5 value.
        """


    @property
    def Data1(self) -> int:
        """
        specifies a 4 byte data block.
        """


    @property
    def Data2(self) -> int:
        """
        specifies a 2 byte data block.
        """


    @property
    def Data3(self) -> int:
        """
        specifies a 2 byte data block.
        """


    @property
    def Data4(self) -> int:
        """
        specifies a 4 byte data block.
        """


    @property
    def Data5(self) -> int:
        """
        specifies a 4 byte data block.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_accessible import XAccessible as XAccessible_1cbc0eb6
    from .x_accessible_relation_set import XAccessibleRelationSet as XAccessibleRelationSet_d8961320
    from .x_accessible_state_set import XAccessibleStateSet as XAccessibleStateSet_a08511e3
    from ..lang.locale import Locale as Locale_70d308fa

class XAccessibleContext(XInterface_8f010a43):
    """
    Implement this interface for exposing various aspects of a class's content.
    
    This interface serves two purposes: On the one hand it gives access to the tree structure in which all accessible objects are organized. Each node in this tree supports this interface. On the other hand it gives access to objects that expose the represented content. That are role, state, name, description, and relations to other objects. Take an OK button of a dialog as an example. Its role is AccessibleRole.BUTTON, its name is \"OK\", and its description is something like \"Accepts all changes made in the dialog\".
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleContext.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleContext']

    def getAccessibleChild(self, i: int) -> 'XAccessible_1cbc0eb6':
        """
        Returns the i-th child of this object.
        
        The order in which the children are enumerated is implementation dependent.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleChildCount(self) -> int:
        """
        Return the number of children.
        
        Returns the number of accessible children of the object.
        """
    def getAccessibleDescription(self) -> str:
        """
        Returns the object's description.
        
        Returns the object's localized description. The description should complement the more generic descriptions given by an object's role and name.
        """
    def getAccessibleIndexInParent(self) -> int:
        """
        Returns the index of this object in its accessible parent.
        
        If you call getAccessibleChild on the object's parent with the index returned by this function you get a reference to this object.
        """
    def getAccessibleName(self) -> str:
        """
        Return the object's localized name.
        
        See XAccessibleContext.getAccessibleRole()'s documentation for the relation between an object's name and role. Names should be unique, at least between children of the same parent, although the uniqueness is neither enforced nor used inside the API.
        """
    def getAccessibleParent(self) -> 'XAccessible_1cbc0eb6':
        """
        Returns the parent of this object.
        
        This function may be called for every node, including the root node, of the accessible tree.
        """
    def getAccessibleRelationSet(self) -> 'XAccessibleRelationSet_d8961320':
        """
        Returns the set of relations defined for this object.
        
        The returned set of relations is a copy of this object's relation set: changing the returned object does not change this object's relations.
        
        There are two ways to represent an empty list of relations: Return an empty reference or return a valid object that contains an empty list.
        """
    def getAccessibleRole(self) -> int:
        """
        Returns the role of this object.
        
        The role is a generic description of an objects function. The relation between role and name is similar to the relation between class and object.
        """
    def getAccessibleStateSet(self) -> 'XAccessibleStateSet_a08511e3':
        """
        Returns the set of states that are currently active for this object.
        
        The returned state set is a copy: Changing the returned state set will not be reflected by changing the object's set of states. See the documentation of XAccessibleStateSet for a description of the individual states.
        """
    def getLocale(self) -> 'Locale_70d308fa':
        """
        Returns the locale of the component.
        
        This locale is used for example to determine the language to use for the name and description texts.

        Raises:
            IllegalAccessibleComponentStateException: ``IllegalAccessibleComponentStateException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .gradient_style import GradientStyle as GradientStyle_b02b0b93
from ..util.color import Color as Color_68e908c5


class Gradient(object):
    """
    Struct Class

    Describes a gradient between two colors.
    
    Many aspects of the gradient are undefined, like the algorithm and color space to use to interpolate between the colors and what \"intensity\" means.

    See Also:
        `API Gradient <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1Gradient.html>`_
    """
    typeName: Literal['com.sun.star.awt.Gradient']

    def __init__(self, Style: typing.Optional[GradientStyle_b02b0b93] = ..., StartColor: typing.Optional[Color_68e908c5] = ..., EndColor: typing.Optional[Color_68e908c5] = ..., Angle: typing.Optional[int] = ..., Border: typing.Optional[int] = ..., XOffset: typing.Optional[int] = ..., YOffset: typing.Optional[int] = ..., StartIntensity: typing.Optional[int] = ..., EndIntensity: typing.Optional[int] = ..., StepCount: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Style (GradientStyle, optional): Style value.
            StartColor (Color, optional): StartColor value.
            EndColor (Color, optional): EndColor value.
            Angle (int, optional): Angle value.
            Border (int, optional): Border value.
            XOffset (int, optional): XOffset value.
            YOffset (int, optional): YOffset value.
            StartIntensity (int, optional): StartIntensity value.
            EndIntensity (int, optional): EndIntensity value.
            StepCount (int, optional): StepCount value.
        """


    @property
    def Style(self) -> GradientStyle_b02b0b93:
        """
        specifies the style of the gradient.
        """


    @property
    def StartColor(self) -> Color_68e908c5:
        """
        specifies the color at the start point of the gradient.
        """


    @property
    def EndColor(self) -> Color_68e908c5:
        """
        specifies the color at the end point of the gradient.
        """


    @property
    def Angle(self) -> int:
        """
        angle of the gradient in 1/10 degree.
        """


    @property
    def Border(self) -> int:
        """
        per cent of the total width where just the start color is used.
        """


    @property
    def XOffset(self) -> int:
        """
        Specifies the X-coordinate, where the gradient begins.
        
        This is effectively the center of the RADIAL, ELLIPTICAL, SQUARE and RECT style gradients.
        """


    @property
    def YOffset(self) -> int:
        """
        Specifies the Y-coordinate, where the gradient begins.
        
        See previous field.
        """


    @property
    def StartIntensity(self) -> int:
        """
        Specifies the intensity at the start point of the gradient.
        
        What that means is undefined.
        """


    @property
    def EndIntensity(self) -> int:
        """
        specifies the intensity at the end point of the gradient.
        """


    @property
    def StepCount(self) -> int:
        """
        Specifies the number of steps of change color.
        
        What that means is undefined.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1

class XMethodParameter(XInterface_8f010a43):
    """
    Reflects a method parameter.
    
    This type is superseded by XParameter, which supports parameters of service constructors as well as parameters of interface methods.

    See Also:
        `API XMethodParameter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XMethodParameter.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XMethodParameter']

    def getName(self) -> str:
        """
        Returns the name of the parameter.
        """
    def getPosition(self) -> int:
        """
        Returns the position of the parameter regarding the IDL method declaration.
        """
    def getType(self) -> 'XTypeDescription_3c210fb1':
        """
        Returns the type of the parameter.
        """
    def isIn(self) -> bool:
        """
        Returns true, if the parameter is declared as [in] or [inout] in IDL.
        """
    def isOut(self) -> bool:
        """
        Returns true, if the parameter is declared as [out] or [inout] in IDL.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.crypto
from typing_extensions import Literal
import typing
from .xxml_security_template import XXMLSecurityTemplate as XXMLSecurityTemplate_79221105
if typing.TYPE_CHECKING:
    from ..wrapper.xxml_element_wrapper import XXMLElementWrapper as XXMLElementWrapper_66c0107c

class XXMLEncryptionTemplate(XXMLSecurityTemplate_79221105):
    """
    Interface of XML encryption template.
    
    This interface represents an encryption template, which is the same as the desired XML encryption element[ EncryptedType ] but some of the nodes may be empty. The empty entities include CipherValue, which is a subset of EncryptedData or EncryptedKey. Empty entities are not allowed in an encryption template when performing decryption.
    
    In some cases, the encryptor or decryptor can determine and locate the EncryptedKey from the encryption template by dereference the RetrievalMethod inside EncryptedData.
    
    In some cases, the EncryptedKey need to be clearly pointed out by the encryption template.
    
    With the help of encryption context, the encryptor or decryptor specifies the key from the KeyInfo in the encryption template.
    
    It isn't a good method to set the EncryptedKey here. In general, there is a RetrievalMethod in EncryptedData by which we can get the EncryptedKey.
    
    And sometimes, in the low level, it is hard to determine what the key is except that the high level application tell the mechanism and parameters.
    
    So I think it will be more simple that the application set the encrypted key information. In this case, the application only need to know the XML schema or DTD and the encryption device. If so, the high level application takes the action of build the EncryptedKey template and references it in the element of EncryptedData. And in this case, the calling to set up EncryptedKey template and target is not necessary, because the encryptor or decryptor can determine and locate the EncryptedKey from the encryption template of EncryptedData by dereference the RetrievalMethod.
    
    In some situation, the high level applications do not want to know anything about crypto devices( May be he must, because the lower level do not know what the key is ). If it gives the key value, it can get EncryptedKey by setting the key template and key value target.

    See Also:
        `API XXMLEncryptionTemplate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XXMLEncryptionTemplate.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.crypto.XXMLEncryptionTemplate']

    def getTarget(self) -> 'XXMLElementWrapper_66c0107c':
        """
        Get the target XML element, i.e.
        
        the element to be encrypted
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.security
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_access_control_context import XAccessControlContext as XAccessControlContext_6d6a10f0
    from .x_action import XAction as XAction_a72e0b36

class XAccessController(XInterface_8f010a43):
    """
    Interface for checking permissions and invoking privileged or restricted actions.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1security_1_1XAccessController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.security.XAccessController']

    def checkPermission(self, perm: object) -> None:
        """
        Determines whether the access request indicated by the specified permission should be allowed or denied, based on the security policy currently in effect.
        
        The semantics are equivalent to the security permission classes of the Java platform.
        
        You can also pass a sequence of permissions (sequence< any >) to check a set of permissions, e.g. for performance reasons. This method quietly returns if the access request is permitted, or throws a suitable AccessControlException otherwise.

        Raises:
            AccessControlException: ``AccessControlException``
        """
    def doPrivileged(self, action: 'XAction_a72e0b36', restriction: 'XAccessControlContext_6d6a10f0') -> object:
        """
        Perform the specified action adding a set of permissions defined by the given XAccessControlContext.
        
        The action is performed with the union of the permissions of the currently installed XAccessControlContext, the given XAccessControlContext and the security policy currently in effect. The latter includes static security, e.g. based on user credentials.
        
        If the given XAccessControlContext is null, then the action is performed only with the permissions of the security policy currently in effect.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
    def doRestricted(self, action: 'XAction_a72e0b36', restriction: 'XAccessControlContext_6d6a10f0') -> object:
        """
        Perform the specified action restricting permissions to the given XAccessControlContext.
        
        The action is performed with the intersection of the permissions of the currently installed XAccessControlContext, the given XAccessControlContext and the security policy currently in effect. The latter includes static security, e.g. based on user credentials.
        
        If the specified XAccessControlContext is null, then the action is performed with unmodified permissions, i.e. the call makes no sense.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
    def getContext(self) -> 'XAccessControlContext_6d6a10f0':
        """
        This method takes a \"snapshot\" of the current calling context and returns it.
        
        This context may then be checked at a later point, possibly in another thread.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.beans
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XFastPropertySet(XInterface_8f010a43):
    """
    provides a fast way of accessing and changing property values.
    
    This interface is an extension to the XPropertySet interface. The get and set methods use handles to access the property values instead of character strings.

    See Also:
        `API XFastPropertySet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XFastPropertySet.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.beans.XFastPropertySet']

    def getFastPropertyValue(self, nHandle: int) -> object:
        """

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def setFastPropertyValue(self, nHandle: int, aValue: object) -> None:
        """
        sets the value to the property with the specified name.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class ConfigurationProvider(XComponent_98dc0ab5, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    manages one, or more, complete sets of configuration data and serves as a factory for objects that provide access to a subset of the configuration.
    
    An implementation is usually obtained from a com.sun.star.lang.ServiceManager. The arguments passed to com.sun.star.lang.XMultiComponentFactory.createInstanceWithArgumentsAndContext() select the configuration data source. Arguments must be provided as com.sun.star.beans.NamedValue or com.sun.star.beans.PropertyValue. If the parameters given are incomplete missing values are taken from the context or the environment. If an instance already exists for the given set of arguments, the existing instance may be reused. In particular, instantiating a provider without explicit arguments to access the default configuration data will always yield the same com.sun.star.configuration.DefaultProvider object.
    
    Some arguments for com.sun.star.lang.XMultiServiceFactory.createInstanceWithArguments() may be given default values during creation of this service. In particular this applies to the parameters \"Locale\" and \"EnableAsync\".
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API ConfigurationProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1ConfigurationProvider.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const

used to specify the category of a spreadsheet function.

See Also:
    `API FunctionCategory <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1FunctionCategory.html>`_
"""
DATABASE: Literal[1]
"""
specifies a database function.
"""
DATETIME: Literal[2]
"""
specifies a function that calculates with dates and/or times.
"""
FINANCIAL: Literal[3]
"""
specifies a financial function.
"""
INFORMATION: Literal[4]
"""
specifies a function that returns information about the cell, the cell contents or the current formula.
"""
LOGICAL: Literal[5]
"""
specifies a boolean function.
"""
MATHEMATICAL: Literal[6]
"""
specifies a common mathematical function
"""
MATRIX: Literal[7]
"""
specifies a matrix function.
"""
STATISTICAL: Literal[8]
"""
specifies a statistical function
"""
SPREADSHEET: Literal[9]
"""
specifies a function that returns information using the spreadsheet contents or specific cell positions.
"""
TEXT: Literal[10]
"""
specifies a text function.
"""
ADDIN: Literal[11]
"""
specifies a common add-in function.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class XStarBasicLibraryInfo(XInterface_8f010a43):
    """
    Interface representing a library and provides access to its modules.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XStarBasicLibraryInfo <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XStarBasicLibraryInfo']

    def getDialogContainer(self) -> 'XNameContainer_cb90e47':
        """
        returns the dialog container giving access to the dialogs stored in the library.
        
        The container has to be returned in any case, no matter if the library is stored embedded, external, or linked.
        """
    def getExternalSourceURL(self) -> str:
        """
        returns an URL describing the location where the library is stored if the library is stored separately (for example not in the main XML file but in a special library format file), an empty string otherwise.
        
        This information can be useful to optimize the access to the library, e.g., for loading on demand.
        """
    def getLinkTargetURL(self) -> str:
        """
        returns an URL describing the location of the library linked to.
        
        HINT: This method can be removed when there is a generic interface for linking. Then the implementation will simply support this \"XLinked\" interface and it can be checked by queryInterface().
        """
    def getModuleContainer(self) -> 'XNameContainer_cb90e47':
        """
        returns the module container giving access to the modules stored in the library.
        
        The container has to be returned in any case, no matter if the library is stored embedded, external, or linked.
        """
    def getName(self) -> str:
        """
        returns the library's name
        """
    def getPassword(self) -> str:
        """
        returns the password, if the library is protected with one, an empty string otherwise.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb.application
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924
    from ...beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ...lang.x_component import XComponent as XComponent_98dc0ab5
    from ...sdbc.x_connection import XConnection as XConnection_a36a0b0c
    from ...sdbc.x_data_source import XDataSource as XDataSource_a2990ae7

class XDatabaseDocumentUI(ABC):
    """
    provides access to the user interface of a database document
    
    This interface is available when a database document has been loaded into a frame, at the controller of this frame.
    
    **since**
    
        OOo 2.2

    See Also:
        `API XDatabaseDocumentUI <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XDatabaseDocumentUI.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.application.XDatabaseDocumentUI']

    def closeSubComponents(self) -> bool:
        """
        closes all sub components of the database document.
        
        During working with the database, the user might open different sub components: forms, reports, tables, queries. If you need to close all those documents, use closeSubComponents, which will gracefully do this.
        
        In a first step, the sub components will be suspended (com.sun.star.frame.XController.suspend()). There are basically two reasons why suspending a single sub component can fail: The user might veto it (she's asked if the document is currently modified), and the component might be uncloseable currently, e.g. due to an open modal dialog, or a long-lasting operation running currently (e.g. printing).
        
        Once all sub components have been suspended, they will, in a second step, be closed. Again, closing might be vetoed by other instances, e.g. by a close listener registered at the component.
        
        **since**
        
            OOo 3.0
        """
    def connect(self) -> None:
        """
        lets the application connect to the database
        
        If the application is already connected, nothing happens. If it is not connected, the application will try to establish a connection by using com.sun.star.sdbc.XDataSource.getConnection() with the current settings, as specified in the com.sun.star.sdb.DataSource.Settings member.
        
        If the connection cannot be established, the respective error message is shown in the application window.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def createComponent(self, ObjectType: int, DocumentDefinition: 'XComponent_98dc0ab5') -> 'XComponent_98dc0ab5':
        """
        creates a new sub component of the given type

        * ``DocumentDefinition`` is an out direction argument.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def createComponentWithArguments(self, ObjectType: int, Arguments: 'typing.Tuple[PropertyValue_c9610c73, ...]', DocumentDefinition: 'XComponent_98dc0ab5') -> 'XComponent_98dc0ab5':
        """
        creates a new sub component of the given type
        
        In opposite to createComponent(), this method allows you to specify additional arguments which are passed to the to-be-loaded component.

        * ``DocumentDefinition`` is an out direction argument.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def identifySubComponent(self, SubComponent: 'XComponent_98dc0ab5') -> 'typing.Tuple[int, str]':
        """
        identifies the given sub component

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isConnected(self) -> bool:
        """
        determines whether the application is currently connected to the database
        """
    def loadComponent(self, ObjectType: int, ObjectName: str, ForEditing: bool) -> 'XComponent_98dc0ab5':
        """
        loads the given sub component of the database document
        
        This method allows programmatic access to the functionality which is present in the UI: it allows opening a table, query, form, or report for either editing or viewing.
        
        This method is a convenience wrapper for API which is also available otherwise. For instance, for loading forms and reports, you could use the com.sun.star.frame.XComponentLoader interface of the com.sun.star.sdb.Forms resp. com.sun.star.sdb.Reports collections.
        
        Note there must exist a connection to the database before you can call this method.
        
        If an error occurs opening the given object, then this is reported to the user via an error dialog.
        
        For the different object types, this means the following

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def loadComponentWithArguments(self, ObjectType: int, ObjectName: str, ForEditing: bool, Arguments: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> 'XComponent_98dc0ab5':
        """
        loads the given sub component of the database document
        
        In opposite to loadComponent(), this method allows you to specify additional arguments which are passed to the to-be-loaded component.
        
        The meaning of the arguments is defined at the service which is effectively created. See the above table for a list of those services.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    @property
    def SubComponents(self) -> 'typing.Tuple[XComponent_98dc0ab5, ...]':
        """
        contains all sub components of the database document
        
        During working with the database, the user might open different sub components: forms, reports, tables, queries. Those components are tracked by the application, and provided in this attribute.
        
        The components here might either be documents (com.sun.star.frame.XModel), controllers (com.sun.star.frame.XController), or frames (com.sun.star.frame.XFrame).
        
        **since**
        
            OOo 3.0
        """

    @property
    def ActiveConnection(self) -> 'XConnection_a36a0b0c':
        """
        provides access to the current connection of the application
        
        Note that the connection returned here is really the working connection of the application. Clients should not misuse it, in particular, closing the connection can yield unexpected results and should definitely be avoided. If you need a separate connection to the data source, use com.sun.star.sdbc.XDataSource.getConnection().
        """

    @property
    def ApplicationMainWindow(self) -> 'XWindow_713b0924':
        """
        provides access to the application's main window
        
        Note that reading this attribute is equivalent to querying the component for the com.sun.star.frame.XController interface, asking the controller for its frame, and asking this frame for its container window.
        """

    @property
    def DataSource(self) -> 'XDataSource_a2990ae7':
        """
        provides access to the data source belong to the database document
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class SimpleFontMetric(object):
    """
    Struct Class

    describes the general metrics of a certain font.

    See Also:
        `API SimpleFontMetric <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1SimpleFontMetric.html>`_
    """
    typeName: Literal['com.sun.star.awt.SimpleFontMetric']

    def __init__(self, Ascent: typing.Optional[int] = ..., Descent: typing.Optional[int] = ..., Leading: typing.Optional[int] = ..., Slant: typing.Optional[int] = ..., FirstChar: typing.Optional[str] = ..., LastChar: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Ascent (int, optional): Ascent value.
            Descent (int, optional): Descent value.
            Leading (int, optional): Leading value.
            Slant (int, optional): Slant value.
            FirstChar (str, optional): FirstChar value.
            LastChar (str, optional): LastChar value.
        """


    @property
    def Ascent(self) -> int:
        """
        specifies the portion of a lower case character that rises above the height of the character \"x\" of the font.
        
        For example, the letters \"b\", \"d\", \"h\", \"k\" and \"l\" have an ascent unequal to 0.
        
        The ascent is measured in pixels, thus the font metric is device dependent.
        """


    @property
    def Descent(self) -> int:
        """
        specifies the portion of a letter falling below the baseline.
        
        For example, the letters \"g\", \"p\", and \"y\" have a descent unequal to 0.
        
        The descent is measured in pixels, thus the font metric is device dependent.
        """


    @property
    def Leading(self) -> int:
        """
        specifies the vertical space between lines of this font; it is also called internal line spacing.
        
        The leading is measured in pixels, thus the font metric is device dependent.
        """


    @property
    def Slant(self) -> int:
        """
        specifies the slant of the characters (italic).
        
        The slant is measured in degrees from 0 to 359.
        """


    @property
    def FirstChar(self) -> str:
        """
        specifies the code of the first printable character in the font.
        """


    @property
    def LastChar(self) -> str:
        """
        specifies the code of the last printable character in the font.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
from typing_extensions import Literal
"""
Const

These values specify the reason why a type conversion failed.

See Also:
    `API FailReason <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1script_1_1FailReason.html>`_
"""
OUT_OF_RANGE: Literal[1]
"""
The given value does not fit in the range of the destination type.
"""
IS_NOT_NUMBER: Literal[2]
"""
The given value cannot be converted to a number.
"""
IS_NOT_ENUM: Literal[3]
"""
The given value cannot be converted to an enumeration.
"""
IS_NOT_BOOL: Literal[4]
"""
The given value cannot be converted to a boolean.
"""
NO_SUCH_INTERFACE: Literal[5]
"""
The given value is not an interface or cannot queried to the right interface.
"""
SOURCE_IS_NO_DERIVED_TYPE: Literal[6]
"""
The given value cannot be converted to right structure or exception type.
"""
TYPE_NOT_SUPPORTED: Literal[7]
"""
The type class of the given value is not supported.
"""
INVALID: Literal[8]
"""
The given value cannot be converted and none of the other reasons match.
"""
NO_DEFAULT_AVAILABLE: Literal[9]
"""
This value is deprecated.

Do not use.
"""
UNKNOWN: Literal[10]
"""
This value is deprecated.

Do not use.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal


class BibliographyDataType(object):
    """
    Const

    These values define the type of bibliographic data like book, journal, magazine, etc.

    See Also:
        `API BibliographyDataType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html>`_
    """
    ARTICLE: Literal[0]
    """
    An article from a journal or magazine.
    """
    BOOK: Literal[1]
    """
    A book with an explicit publisher.
    """
    BOOKLET: Literal[2]
    """
    A work that is printed and bound, but without a named publisher or sponsoring institution.
    """
    CONFERENCE: Literal[3]
    """
    An article in the proceedings of a conference.
    
    This entry is identical to the \"inproceedings\" entry and is included for compatibility with BiBTex.
    """
    INBOOK: Literal[4]
    """
    A part of a book, which may be a chapter and/or a range of pages.
    """
    INCOLLECTION: Literal[5]
    """
    A part of a book with its own title.
    """
    INPROCEEDINGS: Literal[6]
    """
    An article in the proceedings of a conference.
    """
    JOURNAL: Literal[7]
    """
    A journal or magazine.
    """
    MANUAL: Literal[8]
    """
    Technical documentation.
    """
    MASTERSTHESIS: Literal[9]
    """
    A Master's thesis.
    """
    MISC: Literal[10]
    """
    This type is used when nothing else seems appropriate.
    """
    PHDTHESIS: Literal[11]
    """
    A PhD thesis.
    """
    PROCEEDINGS: Literal[12]
    """
    The proceedings of a conference.
    """
    TECHREPORT: Literal[13]
    """
    A report published by a school or other institution, usually numbered within a series.
    """
    UNPUBLISHED: Literal[14]
    """
    A document with an author and title, but not formally published.
    """
    EMAIL: Literal[15]
    """
    An eMail document.
    """
    WWW: Literal[16]
    """
    A Web document.
    """
    CUSTOM1: Literal[17]
    """
    A user defined document type.
    """
    CUSTOM2: Literal[18]
    """
    A user defined document type.
    """
    CUSTOM3: Literal[19]
    """
    A user defined document type.
    """
    CUSTOM4: Literal[20]
    """
    A user defined document type.
    """
    CUSTOM5: Literal[21]
    """
    A user defined document type.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Do NOT insert any new values! Locale data number format creation must match these values! Number formatter internals must match these values!

Number format indices to be passed as the index argument to XNumberFormatCode.getFormatCode() or com.sun.star.util.XNumberFormatTypes.getFormatIndex().

Each locale can support up to about 5000 arbitrary format codes. But for backward compatibility reasons, each locale MUST support some predefined format codes. These predefined format codes are accessed through indices as the following, and the locale data format code definitions in i18npool/source/localedata/data/*.xml MUST have matching entries in the form

<FormatElement formatindex=\"0\">

(see also FormatElement.formatIndex()).

The index values are also used to define the enum NfIndexTableOffset in file svtools/inc/zforlist.hxx

Note: This index has nothing to do with the index key used internally by the number formatter.

Date formats may have a comment of DIN/EN/ISO, meaning

Some names of date format constants indicate a special behavior of those formats in StarOffice 5.2 or older. Those are:

See Also:
    `API NumberFormatIndex <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1NumberFormatIndex.html>`_
"""
NUMBER_START: Literal[0]
"""
Start of simple numerical formats (first format)
"""
NUMBER_STANDARD: Literal[0]
"""
The \"General\" standard format
formatindex=\"0\".
"""
NUMBER_INT: Literal[1]
"""
0
Integer number
formatindex=\"1\"
"""
NUMBER_DEC2: Literal[2]
"""
0.00
Decimal number with 2 decimals
formatindex=\"2\"
"""
NUMBER_1000INT: Literal[3]
"""
#,##0
Integer number with group separator
formatindex=\"3\"
"""
NUMBER_1000DEC2: Literal[4]
"""
#,##0.00
Decimal number with group separator
formatindex=\"4\"
"""
NUMBER_SYSTEM: Literal[5]
"""
#,##0.00
In SO5/Win this format was retrieved from the Regional Settings
formatindex=\"5\"
"""
NUMBER_END: Literal[5]
"""
End of simple numerical formats (last format)
"""
SCIENTIFIC_START: Literal[6]
"""
Start of Scientific formats (first format)
"""
SCIENTIFIC_000E000: Literal[6]
"""
0.00E+000
Number in scientific notation with exponent in 3 digit placeholders
formatindex=\"6\"
"""
SCIENTIFIC_000E00: Literal[7]
"""
0.00E+00
Number in scientific notation with exponent in 2 digit placeholders
formatindex=\"7\"
"""
SCIENTIFIC_END: Literal[7]
"""
End of Scientific formats (last format)
"""
PERCENT_START: Literal[8]
"""
Start of Percent formats (first format)
"""
PERCENT_INT: Literal[8]
"""
0%
Percentage format, rounded to integer
formatindex=\"8\"
"""
PERCENT_DEC2: Literal[9]
"""
0.00%
Percentage format, rounded to 2 decimals
formatindex=\"9\"
"""
PERCENT_END: Literal[9]
"""
End of Percent formats (last format)
"""
FRACTION_START: Literal[10]
"""
Start of Fraction formats (first format)
"""
FRACTION_1: Literal[10]
FRACTION_2: Literal[11]
FRACTION_END: Literal[11]
"""
End of Fraction formats (last format)
"""
CURRENCY_START: Literal[12]
"""
Start of Currency formats (first format)
"""
CURRENCY_1000INT: Literal[12]
"""
#,##0 DM
Integer currency format with group separator
formatindex=\"12\"
"""
CURRENCY_1000DEC2: Literal[13]
"""
#,##0.00 DM
Decimal currency format with group separator
formatindex=\"13\"
"""
CURRENCY_1000INT_RED: Literal[14]
"""
#,##0 DM
Integer currency format with negative in red
formatindex=\"14\"
"""
CURRENCY_1000DEC2_RED: Literal[15]
"""
#,##0.00 DM
Decimal currency format with negative in red
formatindex=\"15\"
"""
CURRENCY_1000DEC2_CCC: Literal[16]
"""
#,##0.00 DEM
Currency in ISO-4217 abbreviation format
formatindex=\"16\"
"""
CURRENCY_1000DEC2_DASHED: Literal[17]
"""
#,##0.– DM
Currency format with dash representing 0 in decimals
formatindex=\"17\"
"""
CURRENCY_END: Literal[17]
"""
End of Currency formats (last format)
"""
DATE_START: Literal[18]
"""
Start of Date formats (first format)
"""
DATE_SYSTEM_SHORT: Literal[18]
"""
08.10.97
see also DATE_SYSTEM_... explanation
formatindex=\"18\"
"""
DATE_SYSTEM_LONG: Literal[19]
"""
Wednesday, 8.

October 1997
see also DATE_SYSTEM_... explanation
formatindex=\"19\"
"""
DATE_SYS_DDMMYY: Literal[20]
"""
08.10.97
see also DATE_SYS_... explanation
formatindex=\"20\"
"""
DATE_SYS_DDMMYYYY: Literal[21]
"""
08.10.1997
see also DATE_SYS_...

explanation
Note: When editing already existing date data this format is forced in order to always edit the full century.
formatindex=\"21\"
"""
DATE_SYS_DMMMYY: Literal[22]
DATE_SYS_DMMMYYYY: Literal[23]
DATE_DIN_DMMMYYYY: Literal[24]
DATE_SYS_DMMMMYYYY: Literal[25]
DATE_DIN_DMMMMYYYY: Literal[26]
DATE_SYS_NNDMMMYY: Literal[27]
"""
Wed, 8. Oct 97
see also DATE_SYS_... explanation
formatindex=\"27\".
"""
DATE_DEF_NNDDMMMYY: Literal[28]
"""
Wed 08.Oct 97
see also DATE_DEF_... explanation
formatindex=\"28\".
"""
DATE_SYS_NNDMMMMYYYY: Literal[29]
"""
Wed, 8. October 1997
see also DATE_SYS_... explanation
formatindex=\"29\".
"""
DATE_SYS_NNNNDMMMMYYYY: Literal[30]
"""
Wednesday, 8. October 1997
formatindex=\"30\".
"""
DATE_DIN_MMDD: Literal[31]
"""
10-08
DIN/EN
formatindex=\"31\"
"""
DATE_DIN_YYMMDD: Literal[32]
"""
97-10-08
DIN/EN
formatindex=\"32\"
"""
DATE_DIN_YYYYMMDD: Literal[33]
"""
1997-10-08
DIN/EN/ISO
formatindex=\"33\"
"""
DATE_SYS_MMYY: Literal[34]
"""
10.97
see also DATE_SYS_... explanation
formatindex=\"34\"
"""
DATE_SYS_DDMMM: Literal[35]
"""
08.Oct
see also DATE_SYS_... explanation
formatindex=\"35\"
"""
DATE_MMMM: Literal[36]
"""
October
formatindex=\"36\".
"""
DATE_QQJJ: Literal[37]
"""
4th quarter 97
formatindex=\"37\"
"""
DATE_WW: Literal[38]
"""
week of year
formatindex=\"38\"
"""
DATE_END: Literal[38]
"""
End of Date formats (last format)
"""
TIME_START: Literal[39]
"""
Start of Time formats (first format)
"""
TIME_HHMM: Literal[39]
"""
HH:MM
Time format with hour and minute
formatindex=\"39\".
"""
TIME_HHMMSS: Literal[40]
"""
HH:MM:SS
Time format with hour, minute and second
formatindex=\"40\".
"""
TIME_HHMMAMPM: Literal[41]
"""
HH:MM AM/PM
Time format with hour, minute and morning/afternoon notation
formatindex=\"41\".
"""
TIME_HHMMSSAMPM: Literal[42]
"""
HH:MM:SS AM/PM
Time format with hour, minute, second and morning/afternoon notation
formatindex=\"42\".
"""
TIME_HH_MMSS: Literal[43]
"""
[HH]:MM:SS
Time format with amount of hours
formatindex=\"43\"
"""
TIME_MMSS00: Literal[44]
"""
MM:SS,00
Time format with second in fraction
formatindex=\"44\".
"""
TIME_HH_MMSS00: Literal[45]
"""
[HH]:MM:SS,00
Time format with amount of hours and seconds with fraction
formatindex=\"45\"
"""
TIME_END: Literal[45]
"""
End of Time formats (last format)
"""
DATETIME_START: Literal[46]
"""
Start of DateTime formats (first format)
"""
DATETIME_SYSTEM_SHORT_HHMM: Literal[46]
"""
08.10.97 01:23 Date/time format
formatindex=\"46\"
"""
DATETIME_SYS_DDMMYYYY_HHMMSS: Literal[47]
"""
08.10.1997 01:23:45 Date/time format with second
Note: When editing already existing date/time data this format is forced in order to always edit the full century.

formatindex=\"47\"
"""
DATETIME_END: Literal[47]
"""
End of DateTime formats (last format)
"""
BOOLEAN: Literal[48]
"""
BOOLEAN format.
"""
TEXT: Literal[49]
"""
Text format.
"""
INDEX_TABLE_ENTRIES: Literal[50]
"""
count of built-in format codes.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..container.x_named import XNamed as XNamed_a6520b08

class TableAutoFormat(XPropertySet_bc180bfa, XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XNamed_a6520b08):
    """
    Service Class

    represents an AutoFormat, containing exactly 16 AutoFormat fields.
    
    Each of the 16 fields contain formatting properties for a table cell at a specific position in the AutoFormat range. The rows of the range are divided into a header row, a footer row and 2 data rows (repeated in turn between header and footer row). The columns are divided similar. This results in 16 different types of cells in the range. The AutoFormats are numbered row by row, then column by column.

    See Also:
        `API TableAutoFormat <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1TableAutoFormat.html>`_
    """
    @property
    def IncludeBackground(self) -> bool:
        """
        specifies whether the background settings from the fields are used.
        """
    @property
    def IncludeBorder(self) -> bool:
        """
        specifies whether the border settings from the fields are used.
        """
    @property
    def IncludeFont(self) -> bool:
        """
        specifies whether the font settings from the fields are used.
        """
    @property
    def IncludeJustify(self) -> bool:
        """
        specifies whether the justification settings from the fields are used.
        """
    @property
    def IncludeNumberFormat(self) -> bool:
        """
        specifies whether the number format settings from the fields are used.
        """
    @property
    def IncludeWidthAndHeight(self) -> bool:
        """
        specifies whether the column widths and row heights should be updated after applying the format.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class WordType(object):
    """
    Const

    Constants to specify the type of words.
    
    Used with XBreakIterator.nextWord(), XBreakIterator.previousWord(), XBreakIterator.getWordBoundary(), XBreakIterator.getWordType(), XBreakIterator.isBeginWord(), XBreakIterator.isEndWord()

    See Also:
        `API WordType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1WordType.html>`_
    """
    ANY_WORD: Literal[0]
    """
    Any \"words\" - words in the meaning of same character types, collection of alphanumeric characters, or collection of non-alphanumeric characters.
    """
    ANYWORD_IGNOREWHITESPACES: Literal[1]
    """
    Any \"words\" - words in the meaning of same character types, collection of alphanumeric characters, or collection of non-alphanumeric characters except blanks.
    """
    DICTIONARY_WORD: Literal[2]
    """
    \"words\" - in the meaning of a collection of alphanumeric characters and some punctuations, like dot for abbreviation.
    """
    WORD_COUNT: Literal[3]
    """
    The mode for counting words, it will combine punctuations and spaces as word trail.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from .x_closeable import XCloseable as XCloseable_98290a86
if typing.TYPE_CHECKING:
    from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
    from .x_database_meta_data import XDatabaseMetaData as XDatabaseMetaData_eafd0d12
    from .x_prepared_statement import XPreparedStatement as XPreparedStatement_fbc80de4
    from .x_statement import XStatement as XStatement_98e90ab1

class XConnection(XCloseable_98290a86):
    """
    represents a connection (session) with a specific database.
    
    Within the context of a Connection, SQL statements are executed and results are returned.
    
    A Connection's database is able to provide information describing its tables, its supported SQL grammar, its stored procedures, and the capabilities of this connection. This information is obtained with the com.sun.star.sdbc.XDatabaseMetaData.getMetaData() method.

    See Also:
        `API XConnection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XConnection']

    def commit(self) -> None:
        """
        makes all changes made since the previous commit/rollback permanent and releases any database locks currently held by the Connection.
        
        This method should be used only when auto-commit mode has been disabled.

        Raises:
            SQLException: ``SQLException``
        """
    def createStatement(self) -> 'XStatement_98e90ab1':
        """
        creates a new com.sun.star.sdbc.Statement object for sending SQL statements to the database.
        
        SQL statements without parameters are normally executed using Statement objects. If the same SQL statement is executed many times, it is more efficient to use a com.sun.star.sdbc.PreparedStatement.
        
        Result sets created using the returned Statement will have forward-only type, and read-only concurrency, by default.
        
        Escape processing for the SQL-Statement is enabled, by default.

        Raises:
            SQLException: ``SQLException``
        """
    def getAutoCommit(self) -> bool:
        """
        gets the current auto-commit state.

        Raises:
            SQLException: ``SQLException``
        """
    def getCatalog(self) -> str:
        """
        returns the Connection's current catalog name.

        Raises:
            SQLException: ``SQLException``
        """
    def getMetaData(self) -> 'XDatabaseMetaData_eafd0d12':
        """
        gets the metadata regarding this connection's database.
        
        A Connection's database is able to provide information describing its tables, its supported SQL grammar, its stored procedures, the capabilities of this connection, and so on. This information is made available through a DatabaseMetaData object.

        Raises:
            SQLException: ``SQLException``
        """
    def getTransactionIsolation(self) -> int:
        """
        gets this Connection's current transaction isolation level.

        Raises:
            SQLException: ``SQLException``
        """
    def getTypeMap(self) -> 'XNameAccess_e2ab0cf6':
        """
        gets the type map object associated with this connection.
        
        Only drivers which implement the custom type mapping facility will return an object otherwise NULL could be returned.
        
        Unless the application has added an entry to the type map, the map returned will be empty.

        Raises:
            SQLException: ``SQLException``
        """
    def isClosed(self) -> bool:
        """
        tests to see if a connection is closed.
        
        Note:  A Connection is automatically closed if no one references it anymore. Certain fatal errors also result in a closed Connection.

        Raises:
            SQLException: ``SQLException``
        """
    def isReadOnly(self) -> bool:
        """
        tests to see if the connection is in read-only mode.

        Raises:
            SQLException: ``SQLException``
        """
    def nativeSQL(self, sql: str) -> str:
        """
        converts the given SQL statement into the system's native SQL grammar.
        
        A driver may convert the JDBC SQL grammar into its system's native SQL grammar prior to sending it; this method returns the native form of the statement that the driver would have sent.

        Raises:
            SQLException: ``SQLException``
        """
    def prepareCall(self, sql: str) -> 'XPreparedStatement_fbc80de4':
        """
        creates a com.sun.star.sdbc.CallableStatement object for calling database stored procedures.
        
        The CallableStatement provides methods for setting up its IN and OUT parameters, and methods for executing the call to a stored procedure.
        
        Note:  This method is optimized for handling stored procedure call statements. Some drivers may send the call statement to the database when the method prepareCall is done;
        others may wait until the CallableStatement is executed. This has no direct effect on users; however, it does affect which method throws certain SQLExceptions. Result sets created using the returned CallableStatement will have forward-only type and read-only concurrency, by default.

        Raises:
            SQLException: ``SQLException``
        """
    def prepareStatement(self, sql: str) -> 'XPreparedStatement_fbc80de4':
        """
        creates a com.sun.star.sdbc.PreparedStatement object for sending parameterized SQL statements to the database.
        
        A SQL statement with or without IN parameters can be pre-compiled and stored in a PreparedStatement object. This object can then be used to efficiently execute this statement multiple times.
        
        Note:  This method is optimized for handling parametric SQL statements that benefit from precompilation. If the driver supports precompilation, the method prepareStatement will send the statement to the database for precompilation. Some drivers may not support precompilation. In this case, the statement may not be sent to the database until the com.sun.star.sdbc.PreparedStatement is executed. This has no direct effect on users; however, it does affect which method throws certain SQLExceptions.
        
        Result sets created using the returned PreparedStatement will have forward-only type and read-only concurrency, by default.
        
        Escape processing for the SQL-Statement is enabled, by default.

        Raises:
            SQLException: ``SQLException``
        """
    def rollback(self) -> None:
        """
        drops all changes made since the previous commit/rollback and releases any database locks currently held by this Connection.
        
        This method should be used only when auto-commit has been disabled.

        Raises:
            SQLException: ``SQLException``
        """
    def setAutoCommit(self, autoCommit: bool) -> None:
        """
        sets this connection's auto-commit mode.
        
        If a connection is in auto-commit mode, then all its SQL statements will be executed and committed as individual transactions. Otherwise, its SQL statements are grouped into transactions that are terminated by a call to either the method com.sun.star.sdbc.XConnection.commit() or the method com.sun.star.sdbc.XConnection.rollback(). By default, new connections are in auto-commit mode.
        
        The commit occurs when the statement completes or the next execute occurs, whichever comes first. In the case of statements returning a ResultSet, the statement completes when the last row of the ResultSet has been retrieved or the ResultSet has been closed. In advanced cases, a single statement may return multiple results as well as output parameter values. In these cases the commit occurs when all results and output parameter values have been retrieved.

        Raises:
            SQLException: ``SQLException``
        """
    def setCatalog(self, catalog: str) -> None:
        """
        sets a catalog name in order to select a subspace of this Connection's database in which to work.
        
        If the driver does not support catalogs, it will silently ignore this request.

        Raises:
            SQLException: ``SQLException``
        """
    def setReadOnly(self, readOnly: bool) -> None:
        """
        puts this connection in read-only mode as a hint to enable database optimizations.
        
        Note:  This method cannot be called while in the middle of a transaction. Calling setReadOnly with TRUE does not necessarily cause writes to be prohibited.

        Raises:
            SQLException: ``SQLException``
        """
    def setTransactionIsolation(self, level: int) -> None:
        """
        attempts to change the transaction isolation level to the one given.
        
        The constants defined in com.sun.star.sdbc.TransactionIsolation are the possible transaction isolation levels.
        
        Note:  This method cannot be called while in the middle of a transaction.

        Raises:
            SQLException: ``SQLException``
        """
    def setTypeMap(self, typeMap: 'XNameAccess_e2ab0cf6') -> None:
        """
        installs the given type map as the type map for this connection.
        
        The type map will be used for the custom mapping of SQL structured types and distinct types.
        
        Only if the driver supports custom type mapping is the setting of a map allowed.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_connection import XConnection as XConnection_a36a0b0c
    from .x_result_set import XResultSet as XResultSet_98e30aa7

class XStatement(XInterface_8f010a43):
    """
    is used for executing a static SQL statement and obtaining the results produced by it.
    
    Only one ResultSet per Statement can be open at any point in time; therefore, if the reading of one ResultSet is interleaved with the reading of another, each must have been generated by different Statements. All statement execute methods implicitly close a statement's current ResultSet if an open one exists.

    See Also:
        `API XStatement <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdbc_1_1XStatement.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdbc.XStatement']

    def execute(self, sql: str) -> bool:
        """
        executes a SQL statement that may return multiple results.
        
        Under some (uncommon) situations a single SQL statement may return multiple result sets and/or update counts. Normally you can ignore this unless you are (1) executing a stored procedure that you know may return multiple results or (2) you are dynamically executing an unknown SQL string. The navigation through multiple results is covered by com.sun.star.sdbc.XMultipleResults.
        
        The execute method executes a SQL statement and indicates the form of the first result. You can then use com.sun.star.sdbc.XMultipleResults.getResultSet() or com.sun.star.sdbc.XMultipleResults.getUpdateCount() to retrieve the result, and com.sun.star.sdbc.XMultipleResults.getMoreResults() to move to any subsequent result(s).

        Raises:
            SQLException: ``SQLException``
        """
    def executeQuery(self, sql: str) -> 'XResultSet_98e30aa7':
        """
        executes a SQL statement that returns a single ResultSet.

        Raises:
            SQLException: ``SQLException``
        """
    def executeUpdate(self, sql: str) -> int:
        """
        executes an SQL INSERT, UPDATE, or DELETE statement.
        
        In addition, SQL statements that return nothing, such as SQL DDL statements, can be executed.

        Raises:
            SQLException: ``SQLException``
        """
    def getConnection(self) -> 'XConnection_a36a0b0c':
        """
        returns the com.sun.star.sdbc.Connection object that produced this Statement object.

        Raises:
            SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .rectangle import Rectangle as Rectangle_84b109e9
from .window_class import WindowClass as WindowClass_99f60ac2
from .x_window_peer import XWindowPeer as XWindowPeer_99760ab0


class WindowDescriptor(object):
    """
    Struct Class

    describes a window.

    See Also:
        `API WindowDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1WindowDescriptor.html>`_
    """
    typeName: Literal['com.sun.star.awt.WindowDescriptor']

    def __init__(self, Type: typing.Optional[WindowClass_99f60ac2] = ..., WindowServiceName: typing.Optional[str] = ..., Parent: typing.Optional[XWindowPeer_99760ab0] = ..., ParentIndex: typing.Optional[int] = ..., Bounds: typing.Optional[Rectangle_84b109e9] = ..., WindowAttributes: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Type (WindowClass, optional): Type value.
            WindowServiceName (str, optional): WindowServiceName value.
            Parent (XWindowPeer, optional): Parent value.
            ParentIndex (int, optional): ParentIndex value.
            Bounds (Rectangle, optional): Bounds value.
            WindowAttributes (int, optional): WindowAttributes value.
        """


    @property
    def Type(self) -> WindowClass_99f60ac2:
        """
        specifies the type of window.
        """


    @property
    def WindowServiceName(self) -> str:
        """
        specifies the name of the component service.
        
        A zero length name means that the VCL creates a blank top, a container, or a simple window. The following service names are defined:
        """


    @property
    def Parent(self) -> XWindowPeer_99760ab0:
        """
        specifies the parent of the component.
        
        If Parent == 0 && ParentIndex == -1, then the window is on the desktop.
        """


    @property
    def ParentIndex(self) -> int:
        """
        specifies the index of the parent window, if available.
        
        If Parent == 0 and this struct is a member of an array, then this is the offset from the beginning of the array to the parent. A value of -1 means desktop.
        """


    @property
    def Bounds(self) -> Rectangle_84b109e9:
        """
        specifies the position and size of the window.
        
        This member is ignored if the window attribute is com.sun.star.awt.WindowAttribute.FULLSIZE.
        """


    @property
    def WindowAttributes(self) -> int:
        """
        specifies the window attributes.
        
        Use one value out of the constant group com.sun.star.awt.WindowAttribute.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
from .x_animation_node import XAnimationNode as XAnimationNode_1cf10eb9

class XTimeContainer(XAnimationNode_1cf10eb9):
    """
    Supported modules.

    See Also:
        `API XTimeContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XTimeContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.animations.XTimeContainer']

    def appendChild(self, newChild: 'XAnimationNode_1cf10eb9') -> 'XAnimationNode_1cf10eb9':
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def insertAfter(self, newChild: 'XAnimationNode_1cf10eb9', refChild: 'XAnimationNode_1cf10eb9') -> 'XAnimationNode_1cf10eb9':
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def insertBefore(self, newChild: 'XAnimationNode_1cf10eb9', refChild: 'XAnimationNode_1cf10eb9') -> 'XAnimationNode_1cf10eb9':
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def removeChild(self, oldChild: 'XAnimationNode_1cf10eb9') -> 'XAnimationNode_1cf10eb9':
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def replaceChild(self, newChild: 'XAnimationNode_1cf10eb9', oldChild: 'XAnimationNode_1cf10eb9') -> 'XAnimationNode_1cf10eb9':
        """

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Constants to classify Unicode characters, returned by XCharacterClassification.getType()

See Also:
    `API UnicodeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1UnicodeType.html>`_
"""
UNASSIGNED: Literal[0]
UPPERCASE_LETTER: Literal[1]
LOWERCASE_LETTER: Literal[2]
TITLECASE_LETTER: Literal[3]
MODIFIER_LETTER: Literal[4]
OTHER_LETTER: Literal[5]
NON_SPACING_MARK: Literal[6]
ENCLOSING_MARK: Literal[7]
COMBINING_SPACING_MARK: Literal[8]
DECIMAL_DIGIT_NUMBER: Literal[9]
LETTER_NUMBER: Literal[10]
OTHER_NUMBER: Literal[11]
SPACE_SEPARATOR: Literal[12]
LINE_SEPARATOR: Literal[13]
PARAGRAPH_SEPARATOR: Literal[14]
CONTROL: Literal[15]
FORMAT: Literal[16]
PRIVATE_USE: Literal[17]
SURROGATE: Literal[18]
DASH_PUNCTUATION: Literal[19]
INITIAL_PUNCTUATION: Literal[20]
FINAL_PUNCTUATION: Literal[21]
CONNECTOR_PUNCTUATION: Literal[22]
OTHER_PUNCTUATION: Literal[23]
MATH_SYMBOL: Literal[24]
CURRENCY_SYMBOL: Literal[25]
MODIFIER_SYMBOL: Literal[26]
OTHER_SYMBOL: Literal[27]
START_PUNCTUATION: Literal[28]
END_PUNCTUATION: Literal[29]
GENERAL_TYPES_COUNT: Literal[30]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class LineJoint(Enum):
    """
    Enum

    

    See Also:
        `API LineJoint <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#aa36e7b530c7d0049f623b0effe54d04f>`_
    """

    BEVEL: 'uno.Enum'
    """
    the edges of the thick lines will be joined by lines
    """
    MIDDLE: 'uno.Enum'
    """
    the middle value between the joints is used
    """
    MITER: 'uno.Enum'
    """
    the lines join at intersections
    """
    NONE: 'uno.Enum'
    """
    the area is not filled.
    
    The text size is only defined by the font properties.
    
    Don't animate this text.
    
    the line is hidden.
    
    the joint between lines will not be connected
    
    the line has no special end.
    """
    ROUND: 'uno.Enum'
    """
    the dash is a point
    
    the lines join with an arc
    
    the line will get a half circle as additional cap
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.style.cell_style import CellStyle as CellStyle
from .._pyi.style.character_properties import CharacterProperties as CharacterProperties
from .._pyi.style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian
from .._pyi.style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex
from .._pyi.style.character_style import CharacterStyle as CharacterStyle
from .._pyi.style.drop_cap_format import DropCapFormat as DropCapFormat
from .._pyi.style.line_spacing import LineSpacing as LineSpacing
from .._pyi.style.numbering_alignment import NumberingAlignment as NumberingAlignment
from .._pyi.style.numbering_level import NumberingLevel as NumberingLevel
from .._pyi.style.numbering_rule import NumberingRule as NumberingRule
from .._pyi.style.page_properties import PageProperties as PageProperties
from .._pyi.style.page_style import PageStyle as PageStyle
from .._pyi.style.paragraph_properties import ParagraphProperties as ParagraphProperties
from .._pyi.style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian
from .._pyi.style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex
from .._pyi.style.paragraph_style import ParagraphStyle as ParagraphStyle
from .._pyi.style.style import Style as Style
from .._pyi.style.style_families import StyleFamilies as StyleFamilies
from .._pyi.style.style_family import StyleFamily as StyleFamily
from .._pyi.style.tab_stop import TabStop as TabStop
from .._pyi.style.x_auto_style import XAutoStyle as XAutoStyle
from .._pyi.style.x_auto_style_family import XAutoStyleFamily as XAutoStyleFamily
from .._pyi.style.x_auto_styles import XAutoStyles as XAutoStyles
from .._pyi.style.x_auto_styles_supplier import XAutoStylesSupplier as XAutoStylesSupplier
from .._pyi.style.x_defaults_supplier import XDefaultsSupplier as XDefaultsSupplier
from .._pyi.style.x_style import XStyle as XStyle
from .._pyi.style.x_style_families_supplier import XStyleFamiliesSupplier as XStyleFamiliesSupplier
from .._pyi.style.x_style_loader import XStyleLoader as XStyleLoader
from .._pyi.style.x_style_loader2 import XStyleLoader2 as XStyleLoader2
from .._pyi.style.x_style_supplier import XStyleSupplier as XStyleSupplier



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XCalculatable(XInterface_8f010a43):
    """
    represents something that can recalculate.

    See Also:
        `API XCalculatable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCalculatable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XCalculatable']

    def calculate(self) -> None:
        """
        recalculates all dirty cells.
        
        This calculates all formula cells which have not yet been calculated after their precedents have changed.
        """
    def calculateAll(self) -> None:
        """
        recalculates all cells.
        """
    def enableAutomaticCalculation(self, bEnabled: bool) -> None:
        """
        enables automatic calculation.
        
        With automatic calculation, each formula cell is recalculated whenever its value is needed after its precedents have changed. The value is needed if the cell is displayed or used in another calculation.
        """
    def isAutomaticCalculationEnabled(self) -> bool:
        """
        returns whether automatic calculation is enabled.
        
        With automatic calculation, each formula cell is recalculated whenever its value is needed after its precedents have changed. The value is needed if the cell is displayed or used in another calculation.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.util
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from ..lang.locale import Locale as Locale_70d308fa

class XNumberFormats(XInterface_8f010a43):
    """
    provides access to multiple NumberFormats.
    
    The number formats are managed by their unique key in the document.

    See Also:
        `API XNumberFormats <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormats.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XNumberFormats']

    def addNew(self, aFormat: str, nLocale: 'Locale_70d308fa') -> int:
        """
        adds a new number format to the list, using a format string.

        Raises:
            com.sun.star.util.MalformedNumberFormatException: ``MalformedNumberFormatException``
        """
    def addNewConverted(self, aFormat: str, nLocale: 'Locale_70d308fa', nNewLocale: 'Locale_70d308fa') -> int:
        """
        adds a new number format to the list, using a format string in a different locale than the desired locale of the resulting number format.

        Raises:
            com.sun.star.util.MalformedNumberFormatException: ``MalformedNumberFormatException``
        """
    def generateFormat(self, nBaseKey: int, nLocale: 'Locale_70d308fa', bThousands: bool, bRed: bool, nDecimals: int, nLeading: int) -> str:
        """
        generates a format string from several parameters without creating an actual number format.
        """
    def getByKey(self, nKey: int) -> 'XPropertySet_bc180bfa':
        """
        """
    def queryKey(self, aFormat: str, nLocale: 'Locale_70d308fa', bScan: bool) -> int:
        """
        finds a number format by its format string and returns its key.
        """
    def queryKeys(self, nType: int, nLocale: 'Locale_70d308fa', bCreate: bool) -> 'typing.Tuple[int, ...]':
        """
        """
    def removeByKey(self, nKey: int) -> None:
        """
        removes a number format from the list.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.sax
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ...io.x_input_stream import XInputStream as XInputStream_98d40ab4


class InputSource(object):
    """
    Struct Class

    specifies the Datasource plus some additional information for the parser.
    
    There are two places where the application will deliver this input source to the parser:

    See Also:
        `API InputSource <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1sax_1_1InputSource.html>`_
    """
    typeName: Literal['com.sun.star.xml.sax.InputSource']

    def __init__(self, aInputStream: typing.Optional[XInputStream_98d40ab4] = ..., sEncoding: typing.Optional[str] = ..., sPublicId: typing.Optional[str] = ..., sSystemId: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            aInputStream (XInputStream, optional): aInputStream value.
            sEncoding (str, optional): sEncoding value.
            sPublicId (str, optional): sPublicId value.
            sSystemId (str, optional): sSystemId value.
        """


    @property
    def aInputStream(self) -> XInputStream_98d40ab4:
        """
        contains the byte input stream of the document.
        """


    @property
    def sEncoding(self) -> str:
        """
        contains the encoding of the data stream.
        
        This is used by the parser to do Unicode conversions.
        
        Note that in general you do not need to specify an encoding. Either it is UTF-8 or UTF-16 which is recognized by the parser or it is specified in the first line of the XML-File ( e.g. ?xml encoding=\"EUC-JP\"? ).
        """


    @property
    def sPublicId(self) -> str:
        """
        contains the public Id of the document, for example, needed in exception-message strings.
        """


    @property
    def sSystemId(self) -> str:
        """
        contains the system ID of the document.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.configuration
from .access_root_element import AccessRootElement as AccessRootElement_7fef1140
from ..util.x_changes_batch import XChangesBatch as XChangesBatch_bb3b0bb9

class UpdateRootElement(AccessRootElement_7fef1140, XChangesBatch_bb3b0bb9):
    """
    Service Class

    provides update control for a hierarchy of configuration items and information about the hierarchy as a whole as well as its root.
    
    Extends AccessRootElement by adding support for collecting changes and applying them to a backend store as a single batch.
    
    An implementation represents the root of a partial hierarchy. [See the documentation for AccessRootElement]. The hierarchy in turn is a view onto a fragment of persistent data tree that can be accessed through several such views, or even several processes, simultaneously.
    
    Elements of the hierarchy, such as descendants of this root element, may support modification by providing appropriate interfaces. Changes done this way initially only affect these objects themselves and other objects within the same hierarchy, such as other descendants of this root element.
    
    The accumulated changes within this hierarchy can be managed using com.sun.star.util.XChangesBatch. Pending changes will become persistent and visible from other overlapping hierarchies only when com.sun.star.util.XChangesBatch.commitChanges() is called. If the hierarchy is disposed or discarded without committing changes, the changes will be lost.

    See Also:
        `API UpdateRootElement <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1UpdateRootElement.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
"""
Const

A collection of tags for the individual components of a color.

Color components usually correspond to physical attributes like the amount of red colorant contained in an output color. This constant field enumerates the most common ones.

**since**

    OOo 2.3

See Also:
    `API ColorComponentTag <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1ColorComponentTag.html>`_
"""
DEVICE: Literal[0]
"""
Unspecified device color value.
"""
RGB_RED: Literal[1]
"""
Red colorant from RGB color space.
"""
RGB_GREEN: Literal[2]
"""
Green colorant from RGB color space.
"""
RGB_BLUE: Literal[3]
"""
Blue colorant from RGB color space.
"""
CMYK_CYAN: Literal[4]
"""
Cyan colorant from CMYK color space.
"""
CMYK_MAGENTA: Literal[5]
"""
Magenta colorant from CMYK color space.
"""
CMYK_YELLOW: Literal[6]
"""
Yellow colorant from CMYK color space.
"""
CMYK_BLACK: Literal[7]
"""
Black colorant from CMYK color space.
"""
CMYKOG_ORANGE: Literal[8]
"""
Orange colorant from hexachrome color space.
"""
CMYKOG_GREEN: Literal[9]
"""
Green colorant from hexachrome color space.
"""
SPOT: Literal[10]
"""
Arbitrary extra spot color, e.g. Pantone.
"""
INDEX: Literal[11]
"""
Index into palette.
"""
ALPHA: Literal[12]
"""
Alpha channel.
"""
GREY: Literal[13]
"""
Grey value. Used for monochrome color spaces.
"""
PREMULTIPLIED_ALPHA: Literal[14]
"""
Premultiplied alpha channel.

Note that this alpha format actually influences the other color components, in that their values are pre-multiplied with the alpha value.
"""
CIEXYZ_X: Literal[15]
"""
CieXYZ X value.
"""
CIEXYZ_Y: Literal[16]
"""
CieXYZ Y value.
"""
CIEXYZ_Z: Literal[17]
"""
CieXYZ Z value.
"""
CIELAB_L: Literal[18]
"""
CieLab L value.
"""
CIELAB_A: Literal[19]
"""
CieLab a value.
"""
CIELAB_B: Literal[20]
"""
CieLab b value.
"""
HSV_H: Literal[21]
"""
HSV H value.
"""
HSV_S: Literal[22]
"""
HSV S value.
"""
HSV_V: Literal[23]
"""
HSV V value.
"""
HSL_H: Literal[24]
"""
HSL H value.
"""
HSL_S: Literal[25]
"""
HSL S value.
"""
HSL_L: Literal[26]
"""
HSL L value.
"""
YCBCR_Y: Literal[27]
"""
YCbCr Y value.
"""
YCBCR_CB: Literal[28]
"""
YCbCr Cb value.
"""
YCBCR_CR: Literal[29]
"""
YCbCr Cr value.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.sax
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..attribute import Attribute as Attribute_85880a0d
    from ..fast_attribute import FastAttribute as FastAttribute_b07f0b9b

class XFastAttributeList(XInterface_8f010a43):
    """
    a container for the attributes of an XML element.
    
    Attributes are separated into known attributes and unknown attributes.
    
    Known attributes have a local name that is known to the XFastTokenHandler registered at the XFastParser which created the sax event containing this attributes. If an attribute also has a namespace, that must be registered at the XFastParser, else this attribute is also unknown even if the local name is known.

    See Also:
        `API XFastAttributeList <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XFastAttributeList.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.sax.XFastAttributeList']

    def getFastAttributes(self) -> 'typing.Tuple[FastAttribute_b07f0b9b, ...]':
        """
        returns a sequence of attributes which names and or namespaces URLS are translated to tokens.
        """
    def getOptionalValue(self, Token: int) -> str:
        """
        retrieves the value of an attribute.
        
        If the attribute name has a namespace that was registered with the XFastParser, Token contains the integer token of the attributes local name from the XFastTokenHandler and the integer token of the namespace combined with an arithmetic or operation.
        """
    def getOptionalValueToken(self, Token: int, Default: int) -> int:
        """
        retrieves the token of an attribute value.
        
        If the attribute name has a namespace that was registered with the XFastParser, Token contains the integer token of the attributes local name from the XFastTokenHandler and the integer token of the namespace combined with an arithmetic or operation.
        """
    def getUnknownAttributes(self) -> 'typing.Tuple[Attribute_85880a0d, ...]':
        """
        returns a sequence of attributes which names and or namespaces URLS can not be translated to tokens.
        """
    def getValue(self, Token: int) -> str:
        """
        retrieves the value of an attribute.
        
        If the attribute name has a namespace that was registered with the XFastParser, Token contains the integer token of the attributes local name from the XFastTokenHandler and the integer token of the namespace combined with an arithmetic or operation.

        Raises:
            SAXException: ``SAXException``
        """
    def getValueToken(self, Token: int) -> int:
        """
        retrieves the token of an attribute value.
        
        If the attribute name has a namespace that was registered with the XFastParser, Token contains the integer token of the attributes local name from the XFastTokenHandler and the integer token of the namespace combined with an arithmetic or operation.

        Raises:
            SAXException: ``SAXException``
        """
    def hasAttribute(self, Token: int) -> bool:
        """
        checks if an attribute is available.
        
        If the attribute name has a namespace that was registered with the XFastParser, Token contains the integer token of the attributes local name from the XFastTokenHandler and the integer token of the namespace combined with an arithmetic or operation.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.accessibility
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_accessible import XAccessible as XAccessible_1cbc0eb6

class XAccessibleTable(XInterface_8f010a43):
    """
    Implement this interface to give access to a two-dimensional table.
    
    The XAccessibleTable interface is used to represent two-dimensional tables. This interface combines the two interfaces javax.accessibility.AccessibleTable and javax.accessibility.AccessibleExtendedTable of the Java Accessibility API (version 1.4).
    
    All XAccessible objects that represent cells or cell-clusters of a table have to be at the same time children of the table. This is necessary to be able to convert row and column indices into child indices and vice versa with the methods XAccessibleTable.getAccessibleIndex(), XAccessibleTable.getAccessibleRow(), and XAccessibleTable.getAccessibleColumn().
    
    The range of valid coordinates for this interface are implementation dependent. However, that range includes at least the intervals from the from the first row or column with the index 0 up to the last (but not including) used row or column as returned by XAccessibleTable.getAccessibleRowCount() and XAccessibleTable.getAccessibleColumnCount(). In case of the Calc the current range of valid indices for retrieving data include the maximal table size–256 columns and 32000 rows–minus one.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XAccessibleTable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleTable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.accessibility.XAccessibleTable']

    def getAccessibleCaption(self) -> 'XAccessible_1cbc0eb6':
        """
        Returns the caption for the table.
        """
    def getAccessibleCellAt(self, nRow: int, nColumn: int) -> 'XAccessible_1cbc0eb6':
        """
        Returns the XAccessible object at the specified row and column in the table.
        
        This method has been renamed from the Java name getAccessibleAt to XAccessibleTable.getAccessibleCellAt() to avoid ambiguities with the XAccessibleComponent.getAccessibleAt() method when accessed, for instance, from StarBasic.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleColumn(self, nChildIndex: int) -> int:
        """
        Translate the given child index into the corresponding column index.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleColumnCount(self) -> int:
        """
        Returns the number of used columns in the table.
        
        The implementation, however, may allow the access of columns beyond this number.
        """
    def getAccessibleColumnDescription(self, nColumn: int) -> str:
        """
        Returns the description text of the specified column in the table.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleColumnExtentAt(self, nRow: int, nColumn: int) -> int:
        """
        Returns the number of columns occupied by the Accessible at the specified row and column in the table.
        
        The result differs from 1 if the specified cell spans multiple columns.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleColumnHeaders(self) -> 'XAccessibleTable':
        """
        Returns the column headers as an XAccessibleTable object.
        
        Content and size of the returned table are implementation dependent.
        """
    def getAccessibleIndex(self, nRow: int, nColumn: int) -> int:
        """
        Returns the child index of the accessible object that spans the specified cell.
        
        This is the same index that would be returned by calling XAccessibleContext.getAccessibleIndexInParent() for that accessible object.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleRow(self, nChildIndex: int) -> int:
        """
        Translate the given child index into the corresponding row index.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleRowCount(self) -> int:
        """
        Returns the number of used rows in the table.
        
        The implementation, however, may allow the access of columns beyond this number.
        """
    def getAccessibleRowDescription(self, nRow: int) -> str:
        """
        Returns the description text of the specified row in the table.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleRowExtentAt(self, nRow: int, nColumn: int) -> int:
        """
        Returns the number of rows occupied by the Accessible at the specified row and column in the table.
        
        The result differs from 1 if the specified cell spans multiple rows.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getAccessibleRowHeaders(self) -> 'XAccessibleTable':
        """
        Returns the row headers as an XAccessibleTable object.
        
        Content and size of the returned table are implementation dependent.
        """
    def getAccessibleSummary(self) -> 'XAccessible_1cbc0eb6':
        """
        Returns the summary description of the table.
        """
    def getSelectedAccessibleColumns(self) -> 'typing.Tuple[int, ...]':
        """
        Returns a list of the indices of completely selected columns in a table.
        """
    def getSelectedAccessibleRows(self) -> 'typing.Tuple[int, ...]':
        """
        Returns a list of the indices of completely selected rows in a table.
        """
    def isAccessibleColumnSelected(self, nColumn: int) -> bool:
        """
        Returns a boolean value indicating whether the specified column is completely selected.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def isAccessibleRowSelected(self, nRow: int) -> bool:
        """
        Returns a boolean value indicating whether the specified row is completely selected.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def isAccessibleSelected(self, nRow: int, nColumn: int) -> bool:
        """
        Returns a boolean value indicating whether the accessible at the specified row and column is selected.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rdf
from typing_extensions import Literal
import typing
from .xuri import XURI as XURI_5682078c
if typing.TYPE_CHECKING:
    from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa
    from .x_node import XNode as XNode_5ee40822
    from .x_resource import XResource as XResource_842709e4

class XNamedGraph(XURI_5682078c):
    """
    represents an RDF named graph that is stored in an RDF Repository.
    
    Note that this interface inherits from XResource: the name of the graph is the string value of the RDF node. This is so that you can easily make RDF statements about named graphs.
    
    Note that instances may be destroyed via XRepository.destroyGraph(). If a graph is destroyed, subsequent calls to addStatement(), removeStatements() will fail with an com.sun.star.container.NoSuchElementException.
    
    **since**
    
        OOo 3.2

    See Also:
        `API XNamedGraph <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rdf_1_1XNamedGraph.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rdf.XNamedGraph']

    def addStatement(self, Subject: 'XResource_842709e4', Predicate: 'XURI_5682078c', Object: 'XNode_5ee40822') -> None:
        """
        adds a RDF statement to the graph.
        
        Note that the ODF elements that can have metadata attached all implement the interface XMetadatable, which inherits from XResource, meaning that you can simply pass them in as arguments here, and it will magically work.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            RepositoryException: ``RepositoryException``
        """
    def clear(self) -> None:
        """
        removes all statements from the graph.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            RepositoryException: ``RepositoryException``
        """
    def getName(self) -> 'XURI_5682078c':
        """
        returns the name of the graph.
        
        The name is unique within the repository.
        """
    def getStatements(self, Subject: 'XResource_842709e4', Predicate: 'XURI_5682078c', Object: 'XNode_5ee40822') -> 'XEnumeration_f2180daa':
        """
        gets matching RDF statements from a graph.
        
        Note that the ODF elements that can have metadata attached all implement the interface XMetadatable, which inherits from XResource, meaning that you can simply pass them in as arguments here, and it will magically work.
        
        Any parameter may be NULL, which acts as a wildcard. For example, to get all statements about myURI: getStatements(myURI, null, null)

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            RepositoryException: ``RepositoryException``
        """
    def removeStatements(self, Subject: 'XResource_842709e4', Predicate: 'XURI_5682078c', Object: 'XNode_5ee40822') -> None:
        """
        removes matching RDF statements from the graph.
        
        Note that the ODF elements that can have metadata attached all implement the interface XMetadatable, which inherits from XResource, meaning that you can simply pass them in as arguments here, and it will magically work.
        
        Any parameter may be NULL, which acts as a wildcard. For example, to remove all statements about myURI: removeStatement(myURI, null, null)

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            RepositoryException: ``RepositoryException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..frame.controller import Controller as Controller_a5330b37
from .spreadsheet_view_pane import SpreadsheetViewPane as SpreadsheetViewPane_1c0b0eb8
from .spreadsheet_view_settings import SpreadsheetViewSettings as SpreadsheetViewSettings_5bbd1085
from .x_activation_broadcaster import XActivationBroadcaster as XActivationBroadcaster_48ce0ff5
from .x_enhanced_mouse_click_broadcaster import XEnhancedMouseClickBroadcaster as XEnhancedMouseClickBroadcaster_d16c12e8
from .x_range_selection import XRangeSelection as XRangeSelection_e1310d0c
from .x_spreadsheet_view import XSpreadsheetView as XSpreadsheetView_f0290d8c
from .x_view_freezable import XViewFreezable as XViewFreezable_d4d40ca4
from .x_view_splitable import XViewSplitable as XViewSplitable_d5640cb4
from ..view.x_selection_supplier import XSelectionSupplier as XSelectionSupplier_fed20e15

class SpreadsheetView(Controller_a5330b37, SpreadsheetViewPane_1c0b0eb8, SpreadsheetViewSettings_5bbd1085, XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XActivationBroadcaster_48ce0ff5, XEnhancedMouseClickBroadcaster_d16c12e8, XRangeSelection_e1310d0c, XSpreadsheetView_f0290d8c, XViewFreezable_d4d40ca4, XViewSplitable_d5640cb4, XSelectionSupplier_fed20e15):
    """
    Service Class

    represents a view of a spreadsheet document.

    See Also:
        `API SpreadsheetView <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetView.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.graphic
from typing_extensions import Literal
import typing
from .x_graphic_provider import XGraphicProvider as XGraphicProvider_b5b0e47
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from .x_graphic import XGraphic as XGraphic_a4da0afc

class XGraphicProvider2(XGraphicProvider_b5b0e47):
    """
    This interface allows operations on multiple graphics with one method call.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API XGraphicProvider2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1graphic_1_1XGraphicProvider2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.graphic.XGraphicProvider2']

    def queryGraphics(self, MediaPropertiesSeq: 'typing.Tuple[PropertyValues_d6470ce6, ...]') -> 'typing.Tuple[XGraphic_a4da0afc, ...]':
        """
        Calling this method returns XGraphic interfaces that hold loaded graphics.
        
        **since**
        
            LibreOffice 6.0

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text.textfield
import typing
from ..text_field import TextField as TextField_90260a56
if typing.TYPE_CHECKING:
    from ..page_number_type import PageNumberType as PageNumberType_c8ed0c55

class PageNumber(TextField_90260a56):
    """
    Service Class

    specifies service of a page number text field.

    See Also:
        `API PageNumber <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1PageNumber.html>`_
    """
    @property
    def NumberingType(self) -> int:
        """
        determines the type of the numbering.
        """
    @property
    def Offset(self) -> int:
        """
        determines an offset value to show a different page number.
        """
    @property
    def SubType(self) -> 'PageNumberType_c8ed0c55':
        """
        determines which page the field refers to.
        """
    @property
    def UserText(self) -> str:
        """
        if the user text string is set then it is displayed when the value of NumberingType is set to com.sun.star.style.NumberingType.CHAR_SPECIAL
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.inspection
from ...inspection.x_property_handler import XPropertyHandler as XPropertyHandler_3e950fbf

class ButtonNavigationHandler(XPropertyHandler_3e950fbf):
    """
    Service Class

    implements a property handler for use with a com.sun.star.inspection.ObjectInspector which is able to enhance the com.sun.star.form.component.CommandButton.ButtonType and com.sun.star.form.component.CommandButton.TargetURL properties of a com.sun.star.form.component.CommandButton.
    
    For this, the two properties are superseded by new versions, where as button type, additional possible values are added for navigating the parent form of the button. For instance, in an com.sun.star.inspection.ObjectInspector using this handler, the user will be able to choose a button type saying \"move to the next record\", which, when chosen, well, moves the parent database form of the button to the next record.

    See Also:
        `API ButtonNavigationHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1ButtonNavigationHandler.html>`_
    """


